/****************************************************************************
** Meta object code from reading C++ file 'qmlobject.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdeclarative-5.116.0/src/kdeclarative/qmlobject.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlobject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDeclarative__QmlObject_t {
    QByteArrayData data[14];
    char stringdata0[226];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDeclarative__QmlObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDeclarative__QmlObject_t qt_meta_stringdata_KDeclarative__QmlObject = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KDeclarative::QmlObject"
QT_MOC_LITERAL(1, 24, 8), // "finished"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 13), // "statusChanged"
QT_MOC_LITERAL(4, 48, 21), // "QQmlComponent::Status"
QT_MOC_LITERAL(5, 70, 22), // "completeInitialization"
QT_MOC_LITERAL(6, 93, 17), // "initialProperties"
QT_MOC_LITERAL(7, 111, 20), // "scheduleExecutionEnd"
QT_MOC_LITERAL(8, 132, 28), // "checkInitializationCompleted"
QT_MOC_LITERAL(9, 161, 6), // "source"
QT_MOC_LITERAL(10, 168, 17), // "translationDomain"
QT_MOC_LITERAL(11, 186, 21), // "initializationDelayed"
QT_MOC_LITERAL(12, 208, 10), // "rootObject"
QT_MOC_LITERAL(13, 219, 6) // "status"

    },
    "KDeclarative::QmlObject\0finished\0\0"
    "statusChanged\0QQmlComponent::Status\0"
    "completeInitialization\0initialProperties\0"
    "scheduleExecutionEnd\0checkInitializationCompleted\0"
    "source\0translationDomain\0initializationDelayed\0"
    "rootObject\0status"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDeclarative__QmlObject[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       5,   54, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    1,   45,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   48,    2, 0x0a /* Public */,
       5,    0,   51,    2, 0x2a /* Public | MethodCloned */,
       7,    0,   52,    2, 0x08 /* Private */,
       8,    0,   53,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QVariantHash,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       9, QMetaType::QUrl, 0x00095103,
      10, QMetaType::QString, 0x00095103,
      11, QMetaType::Bool, 0x00095103,
      12, QMetaType::QObjectStar, 0x00095001,
      13, 0x80000000 | 4, 0x00495009,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       1,

       0        // eod
};

void KDeclarative::QmlObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QmlObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->finished(); break;
        case 1: _t->statusChanged((*reinterpret_cast< QQmlComponent::Status(*)>(_a[1]))); break;
        case 2: _t->completeInitialization((*reinterpret_cast< const QVariantHash(*)>(_a[1]))); break;
        case 3: _t->completeInitialization(); break;
        case 4: _t->d->scheduleExecutionEnd(); break;
        case 5: _t->d->checkInitializationCompleted(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QmlObject::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QmlObject::finished)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QmlObject::*)(QQmlComponent::Status );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QmlObject::statusChanged)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QmlObject *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QUrl*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->translationDomain(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isInitializationDelayed(); break;
        case 3: *reinterpret_cast< QObject**>(_v) = _t->rootObject(); break;
        case 4: *reinterpret_cast< QQmlComponent::Status*>(_v) = _t->status(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QmlObject *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast< QUrl*>(_v)); break;
        case 1: _t->setTranslationDomain(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setInitializationDelayed(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_KDeclarative__QmlObject[] = {
    QMetaObject::SuperData::link<QQmlComponent::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject KDeclarative::QmlObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KDeclarative__QmlObject.data,
    qt_meta_data_KDeclarative__QmlObject,
    qt_static_metacall,
    qt_meta_extradata_KDeclarative__QmlObject,
    nullptr
} };


const QMetaObject *KDeclarative::QmlObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDeclarative::QmlObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDeclarative__QmlObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDeclarative::QmlObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KDeclarative::QmlObject::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDeclarative::QmlObject::statusChanged(QQmlComponent::Status _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
