/****************************************************************************
** Meta object code from reading C++ file 'MimeDataWrapper.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/draganddrop/MimeDataWrapper.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MimeDataWrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MimeDataWrapper_t {
    QByteArrayData data[14];
    char stringdata0[111];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MimeDataWrapper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MimeDataWrapper_t qt_meta_stringdata_MimeDataWrapper = {
    {
QT_MOC_LITERAL(0, 0, 15), // "MimeDataWrapper"
QT_MOC_LITERAL(1, 16, 18), // "getDataAsByteArray"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 6), // "format"
QT_MOC_LITERAL(4, 43, 4), // "text"
QT_MOC_LITERAL(5, 48, 4), // "html"
QT_MOC_LITERAL(6, 53, 3), // "url"
QT_MOC_LITERAL(7, 57, 4), // "urls"
QT_MOC_LITERAL(8, 62, 5), // "color"
QT_MOC_LITERAL(9, 68, 6), // "source"
QT_MOC_LITERAL(10, 75, 7), // "formats"
QT_MOC_LITERAL(11, 83, 7), // "hasUrls"
QT_MOC_LITERAL(12, 91, 8), // "mimeData"
QT_MOC_LITERAL(13, 100, 10) // "QMimeData*"

    },
    "MimeDataWrapper\0getDataAsByteArray\0\0"
    "format\0text\0html\0url\0urls\0color\0source\0"
    "formats\0hasUrls\0mimeData\0QMimeData*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MimeDataWrapper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       9,   22, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x02 /* Public */,

 // methods: parameters
    QMetaType::QByteArray, QMetaType::QString,    3,

 // properties: name, type, flags
       4, QMetaType::QString, 0x00095401,
       5, QMetaType::QString, 0x00095401,
       6, QMetaType::QUrl, 0x00095401,
       7, QMetaType::QJsonArray, 0x00095401,
       8, QMetaType::QVariant, 0x00095401,
       9, QMetaType::QVariant, 0x00095401,
      10, QMetaType::QStringList, 0x00095401,
      11, QMetaType::Bool, 0x00095401,
      12, 0x80000000 | 13, 0x00095409,

       0        // eod
};

void MimeDataWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MimeDataWrapper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QByteArray _r = _t->getDataAsByteArray((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<MimeDataWrapper *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->text(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->html(); break;
        case 2: *reinterpret_cast< QUrl*>(_v) = _t->url(); break;
        case 3: *reinterpret_cast< QJsonArray*>(_v) = _t->urls(); break;
        case 4: *reinterpret_cast< QVariant*>(_v) = _t->color(); break;
        case 5: *reinterpret_cast< QVariant*>(_v) = _t->source(); break;
        case 6: *reinterpret_cast< QStringList*>(_v) = _t->formats(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->hasUrls(); break;
        case 8: *reinterpret_cast< QMimeData**>(_v) = _t->mimeData(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject MimeDataWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_MimeDataWrapper.data,
    qt_meta_data_MimeDataWrapper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MimeDataWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeDataWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MimeDataWrapper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MimeDataWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
