/****************************************************************************
** Meta object code from reading C++ file 'keysequencehelper.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrols/private/keysequencehelper.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keysequencehelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KeySequenceHelper_t {
    QByteArrayData data[19];
    char stringdata0[283];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KeySequenceHelper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KeySequenceHelper_t qt_meta_stringdata_KeySequenceHelper = {
    {
QT_MOC_LITERAL(0, 0, 17), // "KeySequenceHelper"
QT_MOC_LITERAL(1, 18, 32), // "checkAgainstShortcutTypesChanged"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 22), // "isKeySequenceAvailable"
QT_MOC_LITERAL(4, 75, 11), // "keySequence"
QT_MOC_LITERAL(5, 87, 10), // "fromString"
QT_MOC_LITERAL(6, 98, 3), // "str"
QT_MOC_LITERAL(7, 102, 18), // "keySequenceIsEmpty"
QT_MOC_LITERAL(8, 121, 21), // "keySequenceNativeText"
QT_MOC_LITERAL(9, 143, 12), // "renderWindow"
QT_MOC_LITERAL(10, 156, 8), // "QWindow*"
QT_MOC_LITERAL(11, 165, 13), // "QQuickWindow*"
QT_MOC_LITERAL(12, 179, 11), // "quickWindow"
QT_MOC_LITERAL(13, 191, 25), // "checkAgainstShortcutTypes"
QT_MOC_LITERAL(14, 217, 13), // "ShortcutTypes"
QT_MOC_LITERAL(15, 231, 12), // "ShortcutType"
QT_MOC_LITERAL(16, 244, 4), // "None"
QT_MOC_LITERAL(17, 249, 17), // "StandardShortcuts"
QT_MOC_LITERAL(18, 267, 15) // "GlobalShortcuts"

    },
    "KeySequenceHelper\0checkAgainstShortcutTypesChanged\0"
    "\0isKeySequenceAvailable\0keySequence\0"
    "fromString\0str\0keySequenceIsEmpty\0"
    "keySequenceNativeText\0renderWindow\0"
    "QWindow*\0QQuickWindow*\0quickWindow\0"
    "checkAgainstShortcutTypes\0ShortcutTypes\0"
    "ShortcutType\0None\0StandardShortcuts\0"
    "GlobalShortcuts"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KeySequenceHelper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       1,   66, // properties
       1,   70, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
       3,    1,   50,    2, 0x02 /* Public */,
       5,    1,   53,    2, 0x02 /* Public */,
       5,    0,   56,    2, 0x22 /* Public | MethodCloned */,
       7,    1,   57,    2, 0x02 /* Public */,
       8,    1,   60,    2, 0x02 /* Public */,
       9,    1,   63,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,

 // methods: parameters
    QMetaType::Bool, QMetaType::QKeySequence,    4,
    QMetaType::QKeySequence, QMetaType::QString,    6,
    QMetaType::QKeySequence,
    QMetaType::Bool, QMetaType::QKeySequence,    4,
    QMetaType::QString, QMetaType::QKeySequence,    4,
    0x80000000 | 10, 0x80000000 | 11,   12,

 // properties: name, type, flags
      13, 0x80000000 | 14, 0x0049510b,

 // properties: notify_signal_id
       0,

 // enums: name, alias, flags, count, data
      14,   15, 0x1,    3,   75,

 // enum data: key, value
      16, uint(KeySequenceHelper::None),
      17, uint(KeySequenceHelper::StandardShortcuts),
      18, uint(KeySequenceHelper::GlobalShortcuts),

       0        // eod
};

void KeySequenceHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KeySequenceHelper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->checkAgainstShortcutTypesChanged(); break;
        case 1: { bool _r = _t->isKeySequenceAvailable((*reinterpret_cast< const QKeySequence(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { QKeySequence _r = _t->fromString((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QKeySequence*>(_a[0]) = std::move(_r); }  break;
        case 3: { QKeySequence _r = _t->fromString();
            if (_a[0]) *reinterpret_cast< QKeySequence*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->keySequenceIsEmpty((*reinterpret_cast< const QKeySequence(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->keySequenceNativeText((*reinterpret_cast< const QKeySequence(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QWindow* _r = _t->renderWindow((*reinterpret_cast< QQuickWindow*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QWindow**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KeySequenceHelper::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KeySequenceHelper::checkAgainstShortcutTypesChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<KeySequenceHelper *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = QFlag(_t->checkAgainstShortcutTypes()); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<KeySequenceHelper *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCheckAgainstShortcutTypes(QFlag(*reinterpret_cast<int*>(_v))); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KeySequenceHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<KeySequenceRecorder::staticMetaObject>(),
    qt_meta_stringdata_KeySequenceHelper.data,
    qt_meta_data_KeySequenceHelper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KeySequenceHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeySequenceHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KeySequenceHelper.stringdata0))
        return static_cast<void*>(this);
    return KeySequenceRecorder::qt_metacast(_clname);
}

int KeySequenceHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KeySequenceRecorder::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KeySequenceHelper::checkAgainstShortcutTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
