/****************************************************************************
** Meta object code from reading C++ file 'DeclarativeDragArea.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/draganddrop/DeclarativeDragArea.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DeclarativeDragArea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DeclarativeDragArea_t {
    QByteArrayData data[29];
    char stringdata0[403];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DeclarativeDragArea_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DeclarativeDragArea_t qt_meta_stringdata_DeclarativeDragArea = {
    {
QT_MOC_LITERAL(0, 0, 19), // "DeclarativeDragArea"
QT_MOC_LITERAL(1, 20, 11), // "dragStarted"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 15), // "delegateChanged"
QT_MOC_LITERAL(4, 49, 17), // "dragActiveChanged"
QT_MOC_LITERAL(5, 67, 13), // "sourceChanged"
QT_MOC_LITERAL(6, 81, 13), // "targetChanged"
QT_MOC_LITERAL(7, 95, 11), // "dataChanged"
QT_MOC_LITERAL(8, 107, 14), // "enabledChanged"
QT_MOC_LITERAL(9, 122, 4), // "drop"
QT_MOC_LITERAL(10, 127, 6), // "action"
QT_MOC_LITERAL(11, 134, 23), // "supportedActionsChanged"
QT_MOC_LITERAL(12, 158, 20), // "defaultActionChanged"
QT_MOC_LITERAL(13, 179, 24), // "startDragDistanceChanged"
QT_MOC_LITERAL(14, 204, 20), // "delegateImageChanged"
QT_MOC_LITERAL(15, 225, 8), // "delegate"
QT_MOC_LITERAL(16, 234, 11), // "QQuickItem*"
QT_MOC_LITERAL(17, 246, 6), // "source"
QT_MOC_LITERAL(18, 253, 6), // "target"
QT_MOC_LITERAL(19, 260, 8), // "mimeData"
QT_MOC_LITERAL(20, 269, 20), // "DeclarativeMimeData*"
QT_MOC_LITERAL(21, 290, 7), // "enabled"
QT_MOC_LITERAL(22, 298, 16), // "supportedActions"
QT_MOC_LITERAL(23, 315, 15), // "Qt::DropActions"
QT_MOC_LITERAL(24, 331, 13), // "defaultAction"
QT_MOC_LITERAL(25, 345, 14), // "Qt::DropAction"
QT_MOC_LITERAL(26, 360, 17), // "startDragDistance"
QT_MOC_LITERAL(27, 378, 13), // "delegateImage"
QT_MOC_LITERAL(28, 392, 10) // "dragActive"

    },
    "DeclarativeDragArea\0dragStarted\0\0"
    "delegateChanged\0dragActiveChanged\0"
    "sourceChanged\0targetChanged\0dataChanged\0"
    "enabledChanged\0drop\0action\0"
    "supportedActionsChanged\0defaultActionChanged\0"
    "startDragDistanceChanged\0delegateImageChanged\0"
    "delegate\0QQuickItem*\0source\0target\0"
    "mimeData\0DeclarativeMimeData*\0enabled\0"
    "supportedActions\0Qt::DropActions\0"
    "defaultAction\0Qt::DropAction\0"
    "startDragDistance\0delegateImage\0"
    "dragActive"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DeclarativeDragArea[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
      10,   88, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    0,   75,    2, 0x06 /* Public */,
       4,    0,   76,    2, 0x06 /* Public */,
       5,    0,   77,    2, 0x06 /* Public */,
       6,    0,   78,    2, 0x06 /* Public */,
       7,    0,   79,    2, 0x06 /* Public */,
       8,    0,   80,    2, 0x06 /* Public */,
       9,    1,   81,    2, 0x06 /* Public */,
      11,    0,   84,    2, 0x06 /* Public */,
      12,    0,   85,    2, 0x06 /* Public */,
      13,    0,   86,    2, 0x06 /* Public */,
      14,    0,   87,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      15, 0x80000000 | 16, 0x0049510f,
      17, 0x80000000 | 16, 0x0049510f,
      18, 0x80000000 | 16, 0x00495009,
      19, 0x80000000 | 20, 0x00095409,
      21, QMetaType::Bool, 0x00495103,
      22, 0x80000000 | 23, 0x0049510b,
      24, 0x80000000 | 25, 0x0049510b,
      26, QMetaType::Int, 0x00495103,
      27, QMetaType::QVariant, 0x00495103,
      28, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       1,
       3,
       4,
       0,
       6,
       8,
       9,
      10,
      11,
       2,

       0        // eod
};

void DeclarativeDragArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DeclarativeDragArea *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->dragStarted(); break;
        case 1: _t->delegateChanged(); break;
        case 2: _t->dragActiveChanged(); break;
        case 3: _t->sourceChanged(); break;
        case 4: _t->targetChanged(); break;
        case 5: _t->dataChanged(); break;
        case 6: _t->enabledChanged(); break;
        case 7: _t->drop((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->supportedActionsChanged(); break;
        case 9: _t->defaultActionChanged(); break;
        case 10: _t->startDragDistanceChanged(); break;
        case 11: _t->delegateImageChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::dragStarted)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::delegateChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::dragActiveChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::sourceChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::targetChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::dataChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::enabledChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::drop)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::supportedActionsChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::defaultActionChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::startDragDistanceChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DeclarativeDragArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeDragArea::delegateImageChanged)) {
                *result = 11;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DeclarativeMimeData* >(); break;
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DeclarativeDragArea *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQuickItem**>(_v) = _t->delegate(); break;
        case 1: *reinterpret_cast< QQuickItem**>(_v) = _t->source(); break;
        case 2: *reinterpret_cast< QQuickItem**>(_v) = _t->source(); break;
        case 3: *reinterpret_cast< DeclarativeMimeData**>(_v) = _t->mimeData(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isEnabled(); break;
        case 5: *reinterpret_cast< Qt::DropActions*>(_v) = _t->supportedActions(); break;
        case 6: *reinterpret_cast< Qt::DropAction*>(_v) = _t->defaultAction(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->startDragDistance(); break;
        case 8: *reinterpret_cast< QVariant*>(_v) = _t->delegateImage(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->dragActive(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DeclarativeDragArea *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDelegate(*reinterpret_cast< QQuickItem**>(_v)); break;
        case 1: _t->setSource(*reinterpret_cast< QQuickItem**>(_v)); break;
        case 4: _t->setEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setSupportedActions(*reinterpret_cast< Qt::DropActions*>(_v)); break;
        case 6: _t->setDefaultAction(*reinterpret_cast< Qt::DropAction*>(_v)); break;
        case 7: _t->setStartDragDistance(*reinterpret_cast< int*>(_v)); break;
        case 8: _t->setDelegateImage(*reinterpret_cast< QVariant*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        DeclarativeDragArea *_t = static_cast<DeclarativeDragArea *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->resetDelegate(); break;
        case 1: _t->resetSource(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DeclarativeDragArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_DeclarativeDragArea.data,
    qt_meta_data_DeclarativeDragArea,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DeclarativeDragArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeDragArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DeclarativeDragArea.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int DeclarativeDragArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void DeclarativeDragArea::dragStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DeclarativeDragArea::delegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DeclarativeDragArea::dragActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DeclarativeDragArea::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DeclarativeDragArea::targetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DeclarativeDragArea::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DeclarativeDragArea::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DeclarativeDragArea::drop(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void DeclarativeDragArea::supportedActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DeclarativeDragArea::defaultActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DeclarativeDragArea::startDragDistanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DeclarativeDragArea::delegateImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
