/****************************************************************************
** Meta object code from reading C++ file 'configmodule.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdeclarative-5.116.0/src/quickaddons/configmodule.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configmodule.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KQuickAddons__ConfigModule_t {
    QByteArrayData data[59];
    char stringdata0[806];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KQuickAddons__ConfigModule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KQuickAddons__ConfigModule_t qt_meta_stringdata_KQuickAddons__ConfigModule = {
    {
QT_MOC_LITERAL(0, 0, 26), // "KQuickAddons::ConfigModule"
QT_MOC_LITERAL(1, 27, 21), // "authActionNameChanged"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 14), // "buttonsChanged"
QT_MOC_LITERAL(4, 65, 16), // "quickHelpChanged"
QT_MOC_LITERAL(5, 82, 16), // "needsSaveChanged"
QT_MOC_LITERAL(6, 99, 25), // "representsDefaultsChanged"
QT_MOC_LITERAL(7, 125, 25), // "needsAuthorizationChanged"
QT_MOC_LITERAL(8, 151, 22), // "rootOnlyMessageChanged"
QT_MOC_LITERAL(9, 174, 25), // "useRootOnlyMessageChanged"
QT_MOC_LITERAL(10, 200, 10), // "pagePushed"
QT_MOC_LITERAL(11, 211, 11), // "QQuickItem*"
QT_MOC_LITERAL(12, 223, 4), // "page"
QT_MOC_LITERAL(13, 228, 11), // "pageRemoved"
QT_MOC_LITERAL(14, 240, 18), // "columnWidthChanged"
QT_MOC_LITERAL(15, 259, 5), // "width"
QT_MOC_LITERAL(16, 265, 19), // "currentIndexChanged"
QT_MOC_LITERAL(17, 285, 5), // "index"
QT_MOC_LITERAL(18, 291, 12), // "depthChanged"
QT_MOC_LITERAL(19, 304, 28), // "passiveNotificationRequested"
QT_MOC_LITERAL(20, 333, 7), // "message"
QT_MOC_LITERAL(21, 341, 7), // "timeout"
QT_MOC_LITERAL(22, 349, 10), // "actionText"
QT_MOC_LITERAL(23, 360, 8), // "QJSValue"
QT_MOC_LITERAL(24, 369, 8), // "callBack"
QT_MOC_LITERAL(25, 378, 32), // "defaultsIndicatorsVisibleChanged"
QT_MOC_LITERAL(26, 411, 4), // "load"
QT_MOC_LITERAL(27, 416, 4), // "save"
QT_MOC_LITERAL(28, 421, 8), // "defaults"
QT_MOC_LITERAL(29, 430, 4), // "push"
QT_MOC_LITERAL(30, 435, 8), // "fileName"
QT_MOC_LITERAL(31, 444, 11), // "propertyMap"
QT_MOC_LITERAL(32, 456, 4), // "item"
QT_MOC_LITERAL(33, 461, 3), // "pop"
QT_MOC_LITERAL(34, 465, 8), // "takeLast"
QT_MOC_LITERAL(35, 474, 23), // "showPassiveNotification"
QT_MOC_LITERAL(36, 498, 28), // "setDefaultsIndicatorsVisible"
QT_MOC_LITERAL(37, 527, 7), // "visible"
QT_MOC_LITERAL(38, 535, 6), // "mainUi"
QT_MOC_LITERAL(39, 542, 7), // "buttons"
QT_MOC_LITERAL(40, 550, 35), // "KQuickAddons::ConfigModule::B..."
QT_MOC_LITERAL(41, 586, 9), // "needsSave"
QT_MOC_LITERAL(42, 596, 18), // "representsDefaults"
QT_MOC_LITERAL(43, 615, 4), // "name"
QT_MOC_LITERAL(44, 620, 11), // "description"
QT_MOC_LITERAL(45, 632, 9), // "quickHelp"
QT_MOC_LITERAL(46, 642, 15), // "rootOnlyMessage"
QT_MOC_LITERAL(47, 658, 18), // "useRootOnlyMessage"
QT_MOC_LITERAL(48, 677, 18), // "needsAuthorization"
QT_MOC_LITERAL(49, 696, 11), // "columnWidth"
QT_MOC_LITERAL(50, 708, 5), // "depth"
QT_MOC_LITERAL(51, 714, 12), // "currentIndex"
QT_MOC_LITERAL(52, 727, 25), // "defaultsIndicatorsVisible"
QT_MOC_LITERAL(53, 753, 6), // "Button"
QT_MOC_LITERAL(54, 760, 18), // "NoAdditionalButton"
QT_MOC_LITERAL(55, 779, 4), // "Help"
QT_MOC_LITERAL(56, 784, 7), // "Default"
QT_MOC_LITERAL(57, 792, 5), // "Apply"
QT_MOC_LITERAL(58, 798, 7) // "Buttons"

    },
    "KQuickAddons::ConfigModule\0"
    "authActionNameChanged\0\0buttonsChanged\0"
    "quickHelpChanged\0needsSaveChanged\0"
    "representsDefaultsChanged\0"
    "needsAuthorizationChanged\0"
    "rootOnlyMessageChanged\0useRootOnlyMessageChanged\0"
    "pagePushed\0QQuickItem*\0page\0pageRemoved\0"
    "columnWidthChanged\0width\0currentIndexChanged\0"
    "index\0depthChanged\0passiveNotificationRequested\0"
    "message\0timeout\0actionText\0QJSValue\0"
    "callBack\0defaultsIndicatorsVisibleChanged\0"
    "load\0save\0defaults\0push\0fileName\0"
    "propertyMap\0item\0pop\0takeLast\0"
    "showPassiveNotification\0"
    "setDefaultsIndicatorsVisible\0visible\0"
    "mainUi\0buttons\0KQuickAddons::ConfigModule::Buttons\0"
    "needsSave\0representsDefaults\0name\0"
    "description\0quickHelp\0rootOnlyMessage\0"
    "useRootOnlyMessage\0needsAuthorization\0"
    "columnWidth\0depth\0currentIndex\0"
    "defaultsIndicatorsVisible\0Button\0"
    "NoAdditionalButton\0Help\0Default\0Apply\0"
    "Buttons"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KQuickAddons__ConfigModule[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
      14,  228, // properties
       2,  284, // enums/sets
       0,    0, // constructors
       0,       // flags
      15,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  154,    2, 0x06 /* Public */,
       3,    0,  155,    2, 0x06 /* Public */,
       4,    0,  156,    2, 0x06 /* Public */,
       5,    0,  157,    2, 0x06 /* Public */,
       6,    0,  158,    2, 0x06 /* Public */,
       7,    0,  159,    2, 0x06 /* Public */,
       8,    0,  160,    2, 0x06 /* Public */,
       9,    0,  161,    2, 0x06 /* Public */,
      10,    1,  162,    2, 0x06 /* Public */,
      13,    0,  165,    2, 0x06 /* Public */,
      14,    1,  166,    2, 0x06 /* Public */,
      16,    1,  169,    2, 0x06 /* Public */,
      18,    1,  172,    2, 0x06 /* Public */,
      19,    4,  175,    2, 0x06 /* Public */,
      25,    0,  184,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      26,    0,  185,    2, 0x0a /* Public */,
      27,    0,  186,    2, 0x0a /* Public */,
      28,    0,  187,    2, 0x0a /* Public */,
      29,    2,  188,    2, 0x0a /* Public */,
      29,    1,  193,    2, 0x2a /* Public | MethodCloned */,
      29,    1,  196,    2, 0x0a /* Public */,
      33,    0,  199,    2, 0x0a /* Public */,
      34,    0,  200,    2, 0x0a /* Public */,
      35,    4,  201,    2, 0x0a /* Public */,
      35,    3,  210,    2, 0x2a /* Public | MethodCloned */,
      35,    2,  217,    2, 0x2a /* Public | MethodCloned */,
      35,    1,  222,    2, 0x2a /* Public | MethodCloned */,
      36,    1,  225,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant, QMetaType::QString, 0x80000000 | 23,   20,   21,   22,   24,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap,   30,   31,
    QMetaType::Void, QMetaType::QString,   30,
    QMetaType::Void, 0x80000000 | 11,   32,
    QMetaType::Void,
    0x80000000 | 11,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant, QMetaType::QString, 0x80000000 | 23,   20,   21,   22,   24,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant, QMetaType::QString,   20,   21,   22,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,   20,   21,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void, QMetaType::Bool,   37,

 // properties: name, type, flags
      38, 0x80000000 | 11, 0x00095409,
      39, 0x80000000 | 40, 0x0049510b,
      41, QMetaType::Bool, 0x00495103,
      42, QMetaType::Bool, 0x00495103,
      43, QMetaType::QString, 0x00095401,
      44, QMetaType::QString, 0x00095401,
      45, QMetaType::QString, 0x00495103,
      46, QMetaType::QString, 0x00495103,
      47, QMetaType::Bool, 0x00495103,
      48, QMetaType::Bool, 0x00495103,
      49, QMetaType::Int, 0x00495103,
      50, QMetaType::Int, 0x00495001,
      51, QMetaType::Int, 0x00495103,
      52, QMetaType::Int, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       3,
       4,
       0,
       0,
       2,
       6,
       7,
       5,
      10,
      12,
      11,
      14,

 // enums: name, alias, flags, count, data
      53,   53, 0x0,    4,  294,
      58,   53, 0x1,    4,  302,

 // enum data: key, value
      54, uint(KQuickAddons::ConfigModule::NoAdditionalButton),
      55, uint(KQuickAddons::ConfigModule::Help),
      56, uint(KQuickAddons::ConfigModule::Default),
      57, uint(KQuickAddons::ConfigModule::Apply),
      54, uint(KQuickAddons::ConfigModule::NoAdditionalButton),
      55, uint(KQuickAddons::ConfigModule::Help),
      56, uint(KQuickAddons::ConfigModule::Default),
      57, uint(KQuickAddons::ConfigModule::Apply),

       0        // eod
};

void KQuickAddons::ConfigModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ConfigModule *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->authActionNameChanged(); break;
        case 1: _t->buttonsChanged(); break;
        case 2: _t->quickHelpChanged(); break;
        case 3: _t->needsSaveChanged(); break;
        case 4: _t->representsDefaultsChanged(); break;
        case 5: _t->needsAuthorizationChanged(); break;
        case 6: _t->rootOnlyMessageChanged(); break;
        case 7: _t->useRootOnlyMessageChanged(); break;
        case 8: _t->pagePushed((*reinterpret_cast< QQuickItem*(*)>(_a[1]))); break;
        case 9: _t->pageRemoved(); break;
        case 10: _t->columnWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->depthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->passiveNotificationRequested((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QJSValue(*)>(_a[4]))); break;
        case 14: _t->defaultsIndicatorsVisibleChanged(); break;
        case 15: _t->load(); break;
        case 16: _t->save(); break;
        case 17: _t->defaults(); break;
        case 18: _t->push((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 19: _t->push((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->push((*reinterpret_cast< QQuickItem*(*)>(_a[1]))); break;
        case 21: _t->pop(); break;
        case 22: { QQuickItem* _r = _t->takeLast();
            if (_a[0]) *reinterpret_cast< QQuickItem**>(_a[0]) = std::move(_r); }  break;
        case 23: _t->showPassiveNotification((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QJSValue(*)>(_a[4]))); break;
        case 24: _t->showPassiveNotification((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 25: _t->showPassiveNotification((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 26: _t->showPassiveNotification((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->setDefaultsIndicatorsVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::authActionNameChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::buttonsChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::quickHelpChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::needsSaveChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::representsDefaultsChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::needsAuthorizationChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::rootOnlyMessageChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::useRootOnlyMessageChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)(QQuickItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::pagePushed)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::pageRemoved)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::columnWidthChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::currentIndexChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::depthChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)(const QString & , const QVariant & , const QString & , const QJSValue & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::passiveNotificationRequested)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (ConfigModule::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigModule::defaultsIndicatorsVisibleChanged)) {
                *result = 14;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ConfigModule *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQuickItem**>(_v) = _t->mainUi(); break;
        case 1: *reinterpret_cast< KQuickAddons::ConfigModule::Buttons*>(_v) = _t->buttons(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->needsSave(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->representsDefaults(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->description(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->quickHelp(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->rootOnlyMessage(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->useRootOnlyMessage(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->needsAuthorization(); break;
        case 10: *reinterpret_cast< int*>(_v) = _t->columnWidth(); break;
        case 11: *reinterpret_cast< int*>(_v) = _t->depth(); break;
        case 12: *reinterpret_cast< int*>(_v) = _t->currentIndex(); break;
        case 13: *reinterpret_cast< int*>(_v) = _t->defaultsIndicatorsVisible(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ConfigModule *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setButtons(*reinterpret_cast< KQuickAddons::ConfigModule::Buttons*>(_v)); break;
        case 2: _t->setNeedsSave(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setRepresentsDefaults(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setQuickHelp(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setRootOnlyMessage(*reinterpret_cast< QString*>(_v)); break;
        case 8: _t->setUseRootOnlyMessage(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setNeedsAuthorization(*reinterpret_cast< bool*>(_v)); break;
        case 10: _t->setColumnWidth(*reinterpret_cast< int*>(_v)); break;
        case 12: _t->setCurrentIndex(*reinterpret_cast< int*>(_v)); break;
        case 13: _t->setDefaultsIndicatorsVisible(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KQuickAddons::ConfigModule::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KQuickAddons__ConfigModule.data,
    qt_meta_data_KQuickAddons__ConfigModule,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KQuickAddons::ConfigModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KQuickAddons::ConfigModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KQuickAddons__ConfigModule.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KQuickAddons::ConfigModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 14;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KQuickAddons::ConfigModule::authActionNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KQuickAddons::ConfigModule::buttonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KQuickAddons::ConfigModule::quickHelpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KQuickAddons::ConfigModule::needsSaveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KQuickAddons::ConfigModule::representsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KQuickAddons::ConfigModule::needsAuthorizationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KQuickAddons::ConfigModule::rootOnlyMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KQuickAddons::ConfigModule::useRootOnlyMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KQuickAddons::ConfigModule::pagePushed(QQuickItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KQuickAddons::ConfigModule::pageRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KQuickAddons::ConfigModule::columnWidthChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KQuickAddons::ConfigModule::currentIndexChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KQuickAddons::ConfigModule::depthChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KQuickAddons::ConfigModule::passiveNotificationRequested(const QString & _t1, const QVariant & _t2, const QString & _t3, const QJSValue & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void KQuickAddons::ConfigModule::defaultsIndicatorsVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
