/****************************************************************************
** Meta object code from reading C++ file 'icondialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/icondialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'icondialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IconDialog_t {
    QByteArrayData data[19];
    char stringdata0[213];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IconDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IconDialog_t qt_meta_stringdata_IconDialog = {
    {
QT_MOC_LITERAL(0, 0, 10), // "IconDialog"
QT_MOC_LITERAL(1, 11, 15), // "iconNameChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 8), // "iconName"
QT_MOC_LITERAL(4, 37, 15), // "iconSizeChanged"
QT_MOC_LITERAL(5, 53, 8), // "iconSize"
QT_MOC_LITERAL(6, 62, 12), // "titleChanged"
QT_MOC_LITERAL(7, 75, 5), // "title"
QT_MOC_LITERAL(8, 81, 11), // "userChanged"
QT_MOC_LITERAL(9, 93, 4), // "user"
QT_MOC_LITERAL(10, 98, 21), // "customLocationChanged"
QT_MOC_LITERAL(11, 120, 14), // "customLocation"
QT_MOC_LITERAL(12, 135, 15), // "modalityChanged"
QT_MOC_LITERAL(13, 151, 18), // "Qt::WindowModality"
QT_MOC_LITERAL(14, 170, 8), // "modality"
QT_MOC_LITERAL(15, 179, 14), // "visibleChanged"
QT_MOC_LITERAL(16, 194, 4), // "open"
QT_MOC_LITERAL(17, 199, 5), // "close"
QT_MOC_LITERAL(18, 205, 7) // "visible"

    },
    "IconDialog\0iconNameChanged\0\0iconName\0"
    "iconSizeChanged\0iconSize\0titleChanged\0"
    "title\0userChanged\0user\0customLocationChanged\0"
    "customLocation\0modalityChanged\0"
    "Qt::WindowModality\0modality\0visibleChanged\0"
    "open\0close\0visible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IconDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       7,   80, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       4,    1,   62,    2, 0x06 /* Public */,
       6,    1,   65,    2, 0x06 /* Public */,
       8,    1,   68,    2, 0x06 /* Public */,
      10,    1,   71,    2, 0x06 /* Public */,
      12,    1,   74,    2, 0x06 /* Public */,
      15,    0,   77,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      16,    0,   78,    2, 0x02 /* Public */,
      17,    0,   79,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::QString, 0x00495001,
       5, QMetaType::Int, 0x00495103,
       7, QMetaType::QString, 0x00495103,
       9, QMetaType::Bool, 0x00495103,
      11, QMetaType::QString, 0x00495103,
      14, 0x80000000 | 13, 0x0049510b,
      18, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,

       0        // eod
};

void IconDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<IconDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->iconNameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->iconSizeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->titleChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->userChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->customLocationChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->modalityChanged((*reinterpret_cast< Qt::WindowModality(*)>(_a[1]))); break;
        case 6: _t->visibleChanged(); break;
        case 7: _t->open(); break;
        case 8: _t->close(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (IconDialog::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IconDialog::iconNameChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (IconDialog::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IconDialog::iconSizeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (IconDialog::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IconDialog::titleChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (IconDialog::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IconDialog::userChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (IconDialog::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IconDialog::customLocationChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (IconDialog::*)(Qt::WindowModality );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IconDialog::modalityChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (IconDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IconDialog::visibleChanged)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<IconDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->iconName(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->iconSize(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->user(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->customLocation(); break;
        case 5: *reinterpret_cast< Qt::WindowModality*>(_v) = _t->modality(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->visible(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<IconDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setIconSize(*reinterpret_cast< int*>(_v)); break;
        case 2: _t->setTitle(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setUser(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setCustomLocation(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setModality(*reinterpret_cast< Qt::WindowModality*>(_v)); break;
        case 6: _t->setVisible(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject IconDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_IconDialog.data,
    qt_meta_data_IconDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *IconDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IconDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IconDialog.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int IconDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void IconDialog::iconNameChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void IconDialog::iconSizeChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void IconDialog::titleChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void IconDialog::userChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void IconDialog::customLocationChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void IconDialog::modalityChanged(Qt::WindowModality _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void IconDialog::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
