/****************************************************************************
** Meta object code from reading C++ file 'DeclarativeDragDropEvent.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/draganddrop/DeclarativeDragDropEvent.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DeclarativeDragDropEvent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DeclarativeDragDropEvent_t {
    QByteArrayData data[15];
    char stringdata0[161];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DeclarativeDragDropEvent_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DeclarativeDragDropEvent_t qt_meta_stringdata_DeclarativeDragDropEvent = {
    {
QT_MOC_LITERAL(0, 0, 24), // "DeclarativeDragDropEvent"
QT_MOC_LITERAL(1, 25, 6), // "accept"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 6), // "action"
QT_MOC_LITERAL(4, 40, 6), // "ignore"
QT_MOC_LITERAL(5, 47, 1), // "x"
QT_MOC_LITERAL(6, 49, 1), // "y"
QT_MOC_LITERAL(7, 51, 7), // "buttons"
QT_MOC_LITERAL(8, 59, 9), // "modifiers"
QT_MOC_LITERAL(9, 69, 8), // "mimeData"
QT_MOC_LITERAL(10, 78, 20), // "DeclarativeMimeData*"
QT_MOC_LITERAL(11, 99, 15), // "possibleActions"
QT_MOC_LITERAL(12, 115, 15), // "Qt::DropActions"
QT_MOC_LITERAL(13, 131, 14), // "proposedAction"
QT_MOC_LITERAL(14, 146, 14) // "Qt::DropAction"

    },
    "DeclarativeDragDropEvent\0accept\0\0"
    "action\0ignore\0x\0y\0buttons\0modifiers\0"
    "mimeData\0DeclarativeMimeData*\0"
    "possibleActions\0Qt::DropActions\0"
    "proposedAction\0Qt::DropAction"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DeclarativeDragDropEvent[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       7,   28, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       4,    0,   27,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,

 // properties: name, type, flags
       5, QMetaType::Int, 0x00095001,
       6, QMetaType::Int, 0x00095001,
       7, QMetaType::Int, 0x00095001,
       8, QMetaType::Int, 0x00095001,
       9, 0x80000000 | 10, 0x00095009,
      11, 0x80000000 | 12, 0x00095009,
      13, 0x80000000 | 14, 0x00095009,

       0        // eod
};

void DeclarativeDragDropEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DeclarativeDragDropEvent *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->accept((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->ignore(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DeclarativeMimeData* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DeclarativeDragDropEvent *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->buttons(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->modifiers(); break;
        case 4: *reinterpret_cast< DeclarativeMimeData**>(_v) = _t->mimeData(); break;
        case 5: *reinterpret_cast< Qt::DropActions*>(_v) = _t->possibleActions(); break;
        case 6: *reinterpret_cast< Qt::DropAction*>(_v) = _t->proposedAction(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DeclarativeDragDropEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DeclarativeDragDropEvent.data,
    qt_meta_data_DeclarativeDragDropEvent,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DeclarativeDragDropEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeDragDropEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DeclarativeDragDropEvent.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeclarativeDragDropEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
