// This file is generated by kconfig_compiler_kf5 from renderer.kcfg.
// All changes you do to this file will be lost.

#include "renderersettings.h"

using namespace PlasmaQtQuickSettings;

RendererSettings::RendererSettings( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "QtQuickRendererSettings" ) );

  KConfigSkeleton::ItemString  *itemRenderLoop;
  itemRenderLoop = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "RenderLoop" ), mRenderLoop );
  addItem( itemRenderLoop, QStringLiteral( "RenderLoop" ) );
  KConfigSkeleton::ItemString  *itemSceneGraphBackend;
  itemSceneGraphBackend = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SceneGraphBackend" ), mSceneGraphBackend );
  addItem( itemSceneGraphBackend, QStringLiteral( "SceneGraphBackend" ) );
  KConfigSkeleton::ItemBool  *itemForceGlCoreProfile;
  itemForceGlCoreProfile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ForceGlCoreProfile" ), mForceGlCoreProfile, false );
  addItem( itemForceGlCoreProfile, QStringLiteral( "ForceGlCoreProfile" ) );
  KConfigSkeleton::ItemBool  *itemGraphicsResetNotifications;
  itemGraphicsResetNotifications = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GraphicsResetNotifications" ), mGraphicsResetNotifications, false );
  addItem( itemGraphicsResetNotifications, QStringLiteral( "GraphicsResetNotifications" ) );
}

RendererSettings::~RendererSettings()
{
}

