/****************************************************************************
** Meta object code from reading C++ file 'calendareventsplugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdeclarative-5.116.0/src/calendarevents/calendareventsplugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendareventsplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CalendarEvents__CalendarEventsPlugin_t {
    QByteArrayData data[21];
    char stringdata0[347];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CalendarEvents__CalendarEventsPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CalendarEvents__CalendarEventsPlugin_t qt_meta_stringdata_CalendarEvents__CalendarEventsPlugin = {
    {
QT_MOC_LITERAL(0, 0, 36), // "CalendarEvents::CalendarEvent..."
QT_MOC_LITERAL(1, 37, 9), // "dataReady"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 43), // "QMultiHash<QDate,CalendarEven..."
QT_MOC_LITERAL(4, 92, 4), // "data"
QT_MOC_LITERAL(5, 97, 13), // "eventModified"
QT_MOC_LITERAL(6, 111, 25), // "CalendarEvents::EventData"
QT_MOC_LITERAL(7, 137, 13), // "modifiedEvent"
QT_MOC_LITERAL(8, 151, 12), // "eventRemoved"
QT_MOC_LITERAL(9, 164, 3), // "uid"
QT_MOC_LITERAL(10, 168, 18), // "alternateDateReady"
QT_MOC_LITERAL(11, 187, 18), // "QHash<QDate,QDate>"
QT_MOC_LITERAL(12, 206, 26), // "alternateCalendarDateReady"
QT_MOC_LITERAL(13, 233, 36), // "QHash<QDate,QCalendar::YearMo..."
QT_MOC_LITERAL(14, 270, 13), // "subLabelReady"
QT_MOC_LITERAL(15, 284, 21), // "QHash<QDate,SubLabel>"
QT_MOC_LITERAL(16, 306, 16), // "SubLabelPriority"
QT_MOC_LITERAL(17, 323, 3), // "Low"
QT_MOC_LITERAL(18, 327, 7), // "Default"
QT_MOC_LITERAL(19, 335, 4), // "High"
QT_MOC_LITERAL(20, 340, 6) // "Urgent"

    },
    "CalendarEvents::CalendarEventsPlugin\0"
    "dataReady\0\0QMultiHash<QDate,CalendarEvents::EventData>\0"
    "data\0eventModified\0CalendarEvents::EventData\0"
    "modifiedEvent\0eventRemoved\0uid\0"
    "alternateDateReady\0QHash<QDate,QDate>\0"
    "alternateCalendarDateReady\0"
    "QHash<QDate,QCalendar::YearMonthDay>\0"
    "subLabelReady\0QHash<QDate,SubLabel>\0"
    "SubLabelPriority\0Low\0Default\0High\0"
    "Urgent"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CalendarEvents__CalendarEventsPlugin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       1,   62, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       5,    1,   47,    2, 0x06 /* Public */,
       8,    1,   50,    2, 0x06 /* Public */,
      10,    1,   53,    2, 0x06 /* Public */,
      12,    1,   56,    2, 0x06 /* Public */,
      14,    1,   59,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, 0x80000000 | 11,    4,
    QMetaType::Void, 0x80000000 | 13,    4,
    QMetaType::Void, 0x80000000 | 15,    4,

 // enums: name, alias, flags, count, data
      16,   16, 0x2,    4,   67,

 // enum data: key, value
      17, uint(CalendarEvents::CalendarEventsPlugin::SubLabelPriority::Low),
      18, uint(CalendarEvents::CalendarEventsPlugin::SubLabelPriority::Default),
      19, uint(CalendarEvents::CalendarEventsPlugin::SubLabelPriority::High),
      20, uint(CalendarEvents::CalendarEventsPlugin::SubLabelPriority::Urgent),

       0        // eod
};

void CalendarEvents::CalendarEventsPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CalendarEventsPlugin *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->dataReady((*reinterpret_cast< const QMultiHash<QDate,CalendarEvents::EventData>(*)>(_a[1]))); break;
        case 1: _t->eventModified((*reinterpret_cast< const CalendarEvents::EventData(*)>(_a[1]))); break;
        case 2: _t->eventRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->alternateDateReady((*reinterpret_cast< const QHash<QDate,QDate>(*)>(_a[1]))); break;
        case 4: _t->alternateCalendarDateReady((*reinterpret_cast< const QHash<QDate,QCalendar::YearMonthDay>(*)>(_a[1]))); break;
        case 5: _t->subLabelReady((*reinterpret_cast< const QHash<QDate,SubLabel>(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CalendarEventsPlugin::*)(const QMultiHash<QDate,CalendarEvents::EventData> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CalendarEventsPlugin::dataReady)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CalendarEventsPlugin::*)(const CalendarEvents::EventData & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CalendarEventsPlugin::eventModified)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (CalendarEventsPlugin::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CalendarEventsPlugin::eventRemoved)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (CalendarEventsPlugin::*)(const QHash<QDate,QDate> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CalendarEventsPlugin::alternateDateReady)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (CalendarEventsPlugin::*)(const QHash<QDate,QCalendar::YearMonthDay> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CalendarEventsPlugin::alternateCalendarDateReady)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (CalendarEventsPlugin::*)(const QHash<QDate,SubLabel> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CalendarEventsPlugin::subLabelReady)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CalendarEvents::CalendarEventsPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_CalendarEvents__CalendarEventsPlugin.data,
    qt_meta_data_CalendarEvents__CalendarEventsPlugin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CalendarEvents::CalendarEventsPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarEvents::CalendarEventsPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CalendarEvents__CalendarEventsPlugin.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CalendarEvents::CalendarEventsPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void CalendarEvents::CalendarEventsPlugin::dataReady(const QMultiHash<QDate,CalendarEvents::EventData> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CalendarEvents::CalendarEventsPlugin::eventModified(const CalendarEvents::EventData & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void CalendarEvents::CalendarEventsPlugin::eventRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void CalendarEvents::CalendarEventsPlugin::alternateDateReady(const QHash<QDate,QDate> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void CalendarEvents::CalendarEventsPlugin::alternateCalendarDateReady(const QHash<QDate,QCalendar::YearMonthDay> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void CalendarEvents::CalendarEventsPlugin::subLabelReady(const QHash<QDate,SubLabel> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
