/****************************************************************************
** Meta object code from reading C++ file 'formats.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kcoreaddons/formats.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'formats.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Formats_t {
    QByteArrayData data[18];
    char stringdata0[241];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Formats_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Formats_t qt_meta_stringdata_Formats = {
    {
QT_MOC_LITERAL(0, 0, 7), // "Formats"
QT_MOC_LITERAL(1, 8, 14), // "formatByteSize"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 4), // "size"
QT_MOC_LITERAL(4, 29, 9), // "precision"
QT_MOC_LITERAL(5, 39, 14), // "formatDuration"
QT_MOC_LITERAL(6, 54, 5), // "msecs"
QT_MOC_LITERAL(7, 60, 30), // "KFormat::DurationFormatOptions"
QT_MOC_LITERAL(8, 91, 7), // "options"
QT_MOC_LITERAL(9, 99, 21), // "formatDecimalDuration"
QT_MOC_LITERAL(10, 121, 13), // "decimalPlaces"
QT_MOC_LITERAL(11, 135, 22), // "formatSpelloutDuration"
QT_MOC_LITERAL(12, 158, 18), // "formatRelativeDate"
QT_MOC_LITERAL(13, 177, 4), // "date"
QT_MOC_LITERAL(14, 182, 19), // "QLocale::FormatType"
QT_MOC_LITERAL(15, 202, 6), // "format"
QT_MOC_LITERAL(16, 209, 22), // "formatRelativeDateTime"
QT_MOC_LITERAL(17, 232, 8) // "dateTime"

    },
    "Formats\0formatByteSize\0\0size\0precision\0"
    "formatDuration\0msecs\0"
    "KFormat::DurationFormatOptions\0options\0"
    "formatDecimalDuration\0decimalPlaces\0"
    "formatSpelloutDuration\0formatRelativeDate\0"
    "date\0QLocale::FormatType\0format\0"
    "formatRelativeDateTime\0dateTime"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Formats[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    2,   64,    2, 0x02 /* Public */,
       1,    1,   69,    2, 0x22 /* Public | MethodCloned */,
       5,    2,   72,    2, 0x02 /* Public */,
       5,    1,   77,    2, 0x22 /* Public | MethodCloned */,
       5,    2,   80,    2, 0x02 /* Public */,
       9,    2,   85,    2, 0x02 /* Public */,
       9,    1,   90,    2, 0x22 /* Public | MethodCloned */,
      11,    1,   93,    2, 0x02 /* Public */,
      12,    2,   96,    2, 0x02 /* Public */,
      16,    2,  101,    2, 0x02 /* Public */,

 // methods: parameters
    QMetaType::QString, QMetaType::Double, QMetaType::Int,    3,    4,
    QMetaType::QString, QMetaType::Double,    3,
    QMetaType::QString, QMetaType::ULongLong, 0x80000000 | 7,    6,    8,
    QMetaType::QString, QMetaType::ULongLong,    6,
    QMetaType::QString, QMetaType::ULongLong, QMetaType::Int,    6,    8,
    QMetaType::QString, QMetaType::ULongLong, QMetaType::Int,    6,   10,
    QMetaType::QString, QMetaType::ULongLong,    6,
    QMetaType::QString, QMetaType::ULongLong,    6,
    QMetaType::QString, QMetaType::QDate, 0x80000000 | 14,   13,   15,
    QMetaType::QString, QMetaType::QDateTime, 0x80000000 | 14,   17,   15,

       0        // eod
};

void Formats::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Formats *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QString _r = _t->formatByteSize((*reinterpret_cast< double(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->formatByteSize((*reinterpret_cast< double(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->formatDuration((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< KFormat::DurationFormatOptions(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->formatDuration((*reinterpret_cast< quint64(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->formatDuration((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->formatDecimalDuration((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->formatDecimalDuration((*reinterpret_cast< quint64(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->formatSpelloutDuration((*reinterpret_cast< quint64(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->formatRelativeDate((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< QLocale::FormatType(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->formatRelativeDateTime((*reinterpret_cast< const QDateTime(*)>(_a[1])),(*reinterpret_cast< QLocale::FormatType(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QLocale::FormatType >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QLocale::FormatType >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Formats::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Formats.data,
    qt_meta_data_Formats,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Formats::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Formats::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Formats.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Formats::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
