/****************************************************************************
** Meta object code from reading C++ file 'eventgenerator.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/eventgenerator.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'eventgenerator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventGenerator_t {
    QByteArrayData data[29];
    char stringdata0[385];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventGenerator_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventGenerator_t qt_meta_stringdata_EventGenerator = {
    {
QT_MOC_LITERAL(0, 0, 14), // "EventGenerator"
QT_MOC_LITERAL(1, 15, 14), // "sendMouseEvent"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 11), // "QQuickItem*"
QT_MOC_LITERAL(4, 43, 4), // "item"
QT_MOC_LITERAL(5, 48, 26), // "EventGenerator::MouseEvent"
QT_MOC_LITERAL(6, 75, 4), // "type"
QT_MOC_LITERAL(7, 80, 1), // "x"
QT_MOC_LITERAL(8, 82, 1), // "y"
QT_MOC_LITERAL(9, 84, 6), // "button"
QT_MOC_LITERAL(10, 91, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(11, 108, 7), // "buttons"
QT_MOC_LITERAL(12, 116, 21), // "Qt::KeyboardModifiers"
QT_MOC_LITERAL(13, 138, 9), // "modifiers"
QT_MOC_LITERAL(14, 148, 23), // "sendMouseEventRecursive"
QT_MOC_LITERAL(15, 172, 14), // "sendWheelEvent"
QT_MOC_LITERAL(16, 187, 10), // "pixelDelta"
QT_MOC_LITERAL(17, 198, 10), // "angleDelta"
QT_MOC_LITERAL(18, 209, 23), // "sendWheelEventRecursive"
QT_MOC_LITERAL(19, 233, 13), // "sendGrabEvent"
QT_MOC_LITERAL(20, 247, 25), // "EventGenerator::GrabEvent"
QT_MOC_LITERAL(21, 273, 22), // "sendGrabEventRecursive"
QT_MOC_LITERAL(22, 296, 10), // "MouseEvent"
QT_MOC_LITERAL(23, 307, 16), // "MouseButtonPress"
QT_MOC_LITERAL(24, 324, 18), // "MouseButtonRelease"
QT_MOC_LITERAL(25, 343, 9), // "MouseMove"
QT_MOC_LITERAL(26, 353, 9), // "GrabEvent"
QT_MOC_LITERAL(27, 363, 9), // "GrabMouse"
QT_MOC_LITERAL(28, 373, 11) // "UngrabMouse"

    },
    "EventGenerator\0sendMouseEvent\0\0"
    "QQuickItem*\0item\0EventGenerator::MouseEvent\0"
    "type\0x\0y\0button\0Qt::MouseButtons\0"
    "buttons\0Qt::KeyboardModifiers\0modifiers\0"
    "sendMouseEventRecursive\0sendWheelEvent\0"
    "pixelDelta\0angleDelta\0sendWheelEventRecursive\0"
    "sendGrabEvent\0EventGenerator::GrabEvent\0"
    "sendGrabEventRecursive\0MouseEvent\0"
    "MouseButtonPress\0MouseButtonRelease\0"
    "MouseMove\0GrabEvent\0GrabMouse\0UngrabMouse"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventGenerator[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       2,  114, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    7,   44,    2, 0x02 /* Public */,
      14,    7,   59,    2, 0x02 /* Public */,
      15,    7,   74,    2, 0x02 /* Public */,
      18,    7,   89,    2, 0x02 /* Public */,
      19,    2,  104,    2, 0x02 /* Public */,
      21,    2,  109,    2, 0x02 /* Public */,

 // methods: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, QMetaType::Int, QMetaType::Int, QMetaType::Int, 0x80000000 | 10, 0x80000000 | 12,    4,    6,    7,    8,    9,   11,   13,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, QMetaType::Int, QMetaType::Int, QMetaType::Int, 0x80000000 | 10, 0x80000000 | 12,    4,    6,    7,    8,    9,   11,   13,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int, QMetaType::QPoint, QMetaType::QPoint, 0x80000000 | 10, 0x80000000 | 12,    4,    7,    8,   16,   17,   11,   13,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int, QMetaType::QPoint, QMetaType::QPoint, 0x80000000 | 10, 0x80000000 | 12,    4,    7,    8,   16,   17,   11,   13,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 20,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 20,    4,    6,

 // enums: name, alias, flags, count, data
      22,   22, 0x0,    3,  124,
      26,   26, 0x0,    2,  130,

 // enum data: key, value
      23, uint(EventGenerator::MouseButtonPress),
      24, uint(EventGenerator::MouseButtonRelease),
      25, uint(EventGenerator::MouseMove),
      27, uint(EventGenerator::GrabMouse),
      28, uint(EventGenerator::UngrabMouse),

       0        // eod
};

void EventGenerator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<EventGenerator *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sendMouseEvent((*reinterpret_cast< QQuickItem*(*)>(_a[1])),(*reinterpret_cast< EventGenerator::MouseEvent(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< Qt::MouseButtons(*)>(_a[6])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[7]))); break;
        case 1: _t->sendMouseEventRecursive((*reinterpret_cast< QQuickItem*(*)>(_a[1])),(*reinterpret_cast< EventGenerator::MouseEvent(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< Qt::MouseButtons(*)>(_a[6])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[7]))); break;
        case 2: _t->sendWheelEvent((*reinterpret_cast< QQuickItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QPoint(*)>(_a[4])),(*reinterpret_cast< const QPoint(*)>(_a[5])),(*reinterpret_cast< Qt::MouseButtons(*)>(_a[6])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[7]))); break;
        case 3: _t->sendWheelEventRecursive((*reinterpret_cast< QQuickItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QPoint(*)>(_a[4])),(*reinterpret_cast< const QPoint(*)>(_a[5])),(*reinterpret_cast< Qt::MouseButtons(*)>(_a[6])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[7]))); break;
        case 4: _t->sendGrabEvent((*reinterpret_cast< QQuickItem*(*)>(_a[1])),(*reinterpret_cast< EventGenerator::GrabEvent(*)>(_a[2]))); break;
        case 5: _t->sendGrabEventRecursive((*reinterpret_cast< QQuickItem*(*)>(_a[1])),(*reinterpret_cast< EventGenerator::GrabEvent(*)>(_a[2]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject EventGenerator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_EventGenerator.data,
    qt_meta_data_EventGenerator,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *EventGenerator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventGenerator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventGenerator.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EventGenerator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
