/****************************************************************************
** Meta object code from reading C++ file 'clipboard.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/clipboard.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clipboard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Clipboard_t {
    QByteArrayData data[13];
    char stringdata0[122];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Clipboard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Clipboard_t qt_meta_stringdata_Clipboard = {
    {
QT_MOC_LITERAL(0, 0, 9), // "Clipboard"
QT_MOC_LITERAL(1, 10, 11), // "modeChanged"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 16), // "QClipboard::Mode"
QT_MOC_LITERAL(4, 40, 4), // "mode"
QT_MOC_LITERAL(5, 45, 14), // "contentChanged"
QT_MOC_LITERAL(6, 60, 16), // "clipboardChanged"
QT_MOC_LITERAL(7, 77, 1), // "m"
QT_MOC_LITERAL(8, 79, 13), // "contentFormat"
QT_MOC_LITERAL(9, 93, 6), // "format"
QT_MOC_LITERAL(10, 100, 5), // "clear"
QT_MOC_LITERAL(11, 106, 7), // "content"
QT_MOC_LITERAL(12, 114, 7) // "formats"

    },
    "Clipboard\0modeChanged\0\0QClipboard::Mode\0"
    "mode\0contentChanged\0clipboardChanged\0"
    "m\0contentFormat\0format\0clear\0content\0"
    "formats"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Clipboard[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       3,   50, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       5,    0,   42,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   43,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
       8,    1,   46,    2, 0x42 /* Public | isScriptable */,
      10,    0,   49,    2, 0x42 /* Public | isScriptable */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    7,

 // methods: parameters
    QMetaType::QVariant, QMetaType::QString,    9,
    QMetaType::Void,

 // properties: name, type, flags
       4, 0x80000000 | 3, 0x0049510b,
      11, QMetaType::QVariant, 0x00495103,
      12, QMetaType::QStringList, 0x00495001,

 // properties: notify_signal_id
       0,
       1,
       1,

       0        // eod
};

void Clipboard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Clipboard *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->modeChanged((*reinterpret_cast< QClipboard::Mode(*)>(_a[1]))); break;
        case 1: _t->contentChanged(); break;
        case 2: _t->clipboardChanged((*reinterpret_cast< QClipboard::Mode(*)>(_a[1]))); break;
        case 3: { QVariant _r = _t->contentFormat((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->clear(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Clipboard::*)(QClipboard::Mode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Clipboard::modeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Clipboard::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Clipboard::contentChanged)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Clipboard *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QClipboard::Mode*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast< QVariant*>(_v) = _t->content(); break;
        case 2: *reinterpret_cast< QStringList*>(_v) = _t->formats(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Clipboard *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMode(*reinterpret_cast< QClipboard::Mode*>(_v)); break;
        case 1: _t->setContent(*reinterpret_cast< QVariant*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_Clipboard[] = {
    QMetaObject::SuperData::link<QClipboard::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject Clipboard::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Clipboard.data,
    qt_meta_data_Clipboard,
    qt_static_metacall,
    qt_meta_extradata_Clipboard,
    nullptr
} };


const QMetaObject *Clipboard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Clipboard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Clipboard.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Clipboard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Clipboard::modeChanged(QClipboard::Mode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Clipboard::contentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
