/****************************************************************************
** Meta object code from reading C++ file 'plotter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/plotter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plotter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PlotData_t {
    QByteArrayData data[13];
    char stringdata0[112];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlotData_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlotData_t qt_meta_stringdata_PlotData = {
    {
QT_MOC_LITERAL(0, 0, 8), // "PlotData"
QT_MOC_LITERAL(1, 9, 12), // "colorChanged"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 13), // "valuesChanged"
QT_MOC_LITERAL(4, 37, 10), // "maxChanged"
QT_MOC_LITERAL(5, 48, 10), // "minChanged"
QT_MOC_LITERAL(6, 59, 12), // "labelChanged"
QT_MOC_LITERAL(7, 72, 5), // "label"
QT_MOC_LITERAL(8, 78, 5), // "color"
QT_MOC_LITERAL(9, 84, 6), // "values"
QT_MOC_LITERAL(10, 91, 12), // "QList<qreal>"
QT_MOC_LITERAL(11, 104, 3), // "max"
QT_MOC_LITERAL(12, 108, 3) // "min"

    },
    "PlotData\0colorChanged\0\0valuesChanged\0"
    "maxChanged\0minChanged\0labelChanged\0"
    "label\0color\0values\0QList<qreal>\0max\0"
    "min"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlotData[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       5,   44, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    0,   40,    2, 0x06 /* Public */,
       4,    0,   41,    2, 0x06 /* Public */,
       5,    0,   42,    2, 0x06 /* Public */,
       6,    0,   43,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       7, QMetaType::QString, 0x00495103,
       8, QMetaType::QColor, 0x00495103,
       9, 0x80000000 | 10, 0x00495009,
      11, QMetaType::QReal, 0x00495001,
      12, QMetaType::QReal, 0x00495001,

 // properties: notify_signal_id
       4,
       0,
       1,
       2,
       3,

       0        // eod
};

void PlotData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PlotData *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->colorChanged(); break;
        case 1: _t->valuesChanged(); break;
        case 2: _t->maxChanged(); break;
        case 3: _t->minChanged(); break;
        case 4: _t->labelChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PlotData::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlotData::colorChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PlotData::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlotData::valuesChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PlotData::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlotData::maxChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (PlotData::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlotData::minChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (PlotData::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlotData::labelChanged)) {
                *result = 4;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<qreal> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<PlotData *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->label(); break;
        case 1: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast< QList<qreal>*>(_v) = _t->values(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->max(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->min(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<PlotData *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject PlotData::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_PlotData.data,
    qt_meta_data_PlotData,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PlotData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlotData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlotData.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PlotData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void PlotData::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlotData::valuesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlotData::maxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlotData::minChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PlotData::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
struct qt_meta_stringdata_Plotter_t {
    QByteArrayData data[26];
    char stringdata0[322];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Plotter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Plotter_t qt_meta_stringdata_Plotter = {
    {
QT_MOC_LITERAL(0, 0, 7), // "Plotter"
QT_MOC_LITERAL(1, 8, 10), // "maxChanged"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 10), // "minChanged"
QT_MOC_LITERAL(4, 31, 17), // "sampleSizeChanged"
QT_MOC_LITERAL(5, 49, 14), // "stackedChanged"
QT_MOC_LITERAL(6, 64, 16), // "autoRangeChanged"
QT_MOC_LITERAL(7, 81, 15), // "rangeMaxChanged"
QT_MOC_LITERAL(8, 97, 15), // "rangeMinChanged"
QT_MOC_LITERAL(9, 113, 16), // "gridColorChanged"
QT_MOC_LITERAL(10, 130, 30), // "horizontalGridLineCountChanged"
QT_MOC_LITERAL(11, 161, 6), // "render"
QT_MOC_LITERAL(12, 168, 9), // "addSample"
QT_MOC_LITERAL(13, 178, 5), // "value"
QT_MOC_LITERAL(14, 184, 12), // "QList<qreal>"
QT_MOC_LITERAL(15, 197, 8), // "dataSets"
QT_MOC_LITERAL(16, 206, 26), // "QQmlListProperty<PlotData>"
QT_MOC_LITERAL(17, 233, 3), // "max"
QT_MOC_LITERAL(18, 237, 3), // "min"
QT_MOC_LITERAL(19, 241, 10), // "sampleSize"
QT_MOC_LITERAL(20, 252, 7), // "stacked"
QT_MOC_LITERAL(21, 260, 9), // "autoRange"
QT_MOC_LITERAL(22, 270, 8), // "rangeMax"
QT_MOC_LITERAL(23, 279, 8), // "rangeMin"
QT_MOC_LITERAL(24, 288, 9), // "gridColor"
QT_MOC_LITERAL(25, 298, 23) // "horizontalGridLineCount"

    },
    "Plotter\0maxChanged\0\0minChanged\0"
    "sampleSizeChanged\0stackedChanged\0"
    "autoRangeChanged\0rangeMaxChanged\0"
    "rangeMinChanged\0gridColorChanged\0"
    "horizontalGridLineCountChanged\0render\0"
    "addSample\0value\0QList<qreal>\0dataSets\0"
    "QQmlListProperty<PlotData>\0max\0min\0"
    "sampleSize\0stacked\0autoRange\0rangeMax\0"
    "rangeMin\0gridColor\0horizontalGridLineCount"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Plotter[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
      10,   90, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    0,   75,    2, 0x06 /* Public */,
       4,    0,   76,    2, 0x06 /* Public */,
       5,    0,   77,    2, 0x06 /* Public */,
       6,    0,   78,    2, 0x06 /* Public */,
       7,    0,   79,    2, 0x06 /* Public */,
       8,    0,   80,    2, 0x06 /* Public */,
       9,    0,   81,    2, 0x06 /* Public */,
      10,    0,   82,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   83,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      12,    1,   84,    2, 0x02 /* Public */,
      12,    1,   87,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void, QMetaType::QReal,   13,
    QMetaType::Void, 0x80000000 | 14,   13,

 // properties: name, type, flags
      15, 0x80000000 | 16, 0x00095009,
      17, QMetaType::QReal, 0x00495001,
      18, QMetaType::QReal, 0x00495001,
      19, QMetaType::Int, 0x00495103,
      20, QMetaType::Bool, 0x00495103,
      21, QMetaType::Bool, 0x00495103,
      22, QMetaType::QReal, 0x00495103,
      23, QMetaType::QReal, 0x00495103,
      24, QMetaType::QColor, 0x00495103,
      25, QMetaType::Int, 0x00495103,

 // properties: notify_signal_id
       0,
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,

       0        // eod
};

void Plotter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Plotter *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->maxChanged(); break;
        case 1: _t->minChanged(); break;
        case 2: _t->sampleSizeChanged(); break;
        case 3: _t->stackedChanged(); break;
        case 4: _t->autoRangeChanged(); break;
        case 5: _t->rangeMaxChanged(); break;
        case 6: _t->rangeMinChanged(); break;
        case 7: _t->gridColorChanged(); break;
        case 8: _t->horizontalGridLineCountChanged(); break;
        case 9: _t->render(); break;
        case 10: _t->addSample((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 11: _t->addSample((*reinterpret_cast< const QList<qreal>(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<qreal> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::maxChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::minChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::sampleSizeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::stackedChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::autoRangeChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::rangeMaxChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::rangeMinChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::gridColorChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Plotter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Plotter::horizontalGridLineCountChanged)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Plotter *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QQmlListProperty<PlotData>*>(_v) = _t->dataSets(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->max(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->min(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->sampleSize(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isStacked(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isAutoRange(); break;
        case 6: *reinterpret_cast< qreal*>(_v) = _t->rangeMax(); break;
        case 7: *reinterpret_cast< qreal*>(_v) = _t->rangeMin(); break;
        case 8: *reinterpret_cast< QColor*>(_v) = _t->gridColor(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->horizontalGridLineCount(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Plotter *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setSampleSize(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setStacked(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setAutoRange(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setRangeMax(*reinterpret_cast< qreal*>(_v)); break;
        case 7: _t->setRangeMin(*reinterpret_cast< qreal*>(_v)); break;
        case 8: _t->setGridColor(*reinterpret_cast< QColor*>(_v)); break;
        case 9: _t->setHorizontalGridLineCount(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Plotter::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_Plotter.data,
    qt_meta_data_Plotter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Plotter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plotter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Plotter.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Plotter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Plotter::maxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Plotter::minChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Plotter::sampleSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Plotter::stackedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Plotter::autoRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Plotter::rangeMaxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Plotter::rangeMinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Plotter::gridColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Plotter::horizontalGridLineCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
