/****************************************************************************
** Meta object code from reading C++ file 'mouseeventlistener.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/mouseeventlistener.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mouseeventlistener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDeclarativeMouseEvent_t {
    QByteArrayData data[16];
    char stringdata0[156];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDeclarativeMouseEvent_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDeclarativeMouseEvent_t qt_meta_stringdata_KDeclarativeMouseEvent = {
    {
QT_MOC_LITERAL(0, 0, 22), // "KDeclarativeMouseEvent"
QT_MOC_LITERAL(1, 23, 15), // "acceptedChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 1), // "x"
QT_MOC_LITERAL(4, 42, 1), // "y"
QT_MOC_LITERAL(5, 44, 7), // "screenX"
QT_MOC_LITERAL(6, 52, 7), // "screenY"
QT_MOC_LITERAL(7, 60, 6), // "button"
QT_MOC_LITERAL(8, 67, 7), // "buttons"
QT_MOC_LITERAL(9, 75, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(10, 92, 9), // "modifiers"
QT_MOC_LITERAL(11, 102, 21), // "Qt::KeyboardModifiers"
QT_MOC_LITERAL(12, 124, 6), // "screen"
QT_MOC_LITERAL(13, 131, 8), // "QScreen*"
QT_MOC_LITERAL(14, 140, 8), // "accepted"
QT_MOC_LITERAL(15, 149, 6) // "source"

    },
    "KDeclarativeMouseEvent\0acceptedChanged\0"
    "\0x\0y\0screenX\0screenY\0button\0buttons\0"
    "Qt::MouseButtons\0modifiers\0"
    "Qt::KeyboardModifiers\0screen\0QScreen*\0"
    "accepted\0source"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDeclarativeMouseEvent[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
      10,   20, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::Int, 0x00095001,
       4, QMetaType::Int, 0x00095001,
       5, QMetaType::Int, 0x00095001,
       6, QMetaType::Int, 0x00095001,
       7, QMetaType::Int, 0x00095001,
       8, 0x80000000 | 9, 0x00095009,
      10, 0x80000000 | 11, 0x00095009,
      12, 0x80000000 | 13, 0x00095409,
      14, QMetaType::Bool, 0x00495103,
      15, QMetaType::Int, 0x00095001,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

       0        // eod
};

void KDeclarativeMouseEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KDeclarativeMouseEvent *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->acceptedChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KDeclarativeMouseEvent::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDeclarativeMouseEvent::acceptedChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<KDeclarativeMouseEvent *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->screenX(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->screenY(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->button(); break;
        case 5: *reinterpret_cast< Qt::MouseButtons*>(_v) = _t->buttons(); break;
        case 6: *reinterpret_cast< Qt::KeyboardModifiers*>(_v) = _t->modifiers(); break;
        case 7: *reinterpret_cast< QScreen**>(_v) = _t->screen(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->isAccepted(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->source(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<KDeclarativeMouseEvent *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 8: _t->setAccepted(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KDeclarativeMouseEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KDeclarativeMouseEvent.data,
    qt_meta_data_KDeclarativeMouseEvent,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KDeclarativeMouseEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDeclarativeMouseEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDeclarativeMouseEvent.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDeclarativeMouseEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KDeclarativeMouseEvent::acceptedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_KDeclarativeWheelEvent_t {
    QByteArrayData data[14];
    char stringdata0[148];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDeclarativeWheelEvent_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDeclarativeWheelEvent_t qt_meta_stringdata_KDeclarativeWheelEvent = {
    {
QT_MOC_LITERAL(0, 0, 22), // "KDeclarativeWheelEvent"
QT_MOC_LITERAL(1, 23, 1), // "x"
QT_MOC_LITERAL(2, 25, 1), // "y"
QT_MOC_LITERAL(3, 27, 7), // "screenX"
QT_MOC_LITERAL(4, 35, 7), // "screenY"
QT_MOC_LITERAL(5, 43, 6), // "deltaX"
QT_MOC_LITERAL(6, 50, 6), // "deltaY"
QT_MOC_LITERAL(7, 57, 5), // "delta"
QT_MOC_LITERAL(8, 63, 7), // "buttons"
QT_MOC_LITERAL(9, 71, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(10, 88, 9), // "modifiers"
QT_MOC_LITERAL(11, 98, 21), // "Qt::KeyboardModifiers"
QT_MOC_LITERAL(12, 120, 11), // "orientation"
QT_MOC_LITERAL(13, 132, 15) // "Qt::Orientation"

    },
    "KDeclarativeWheelEvent\0x\0y\0screenX\0"
    "screenY\0deltaX\0deltaY\0delta\0buttons\0"
    "Qt::MouseButtons\0modifiers\0"
    "Qt::KeyboardModifiers\0orientation\0"
    "Qt::Orientation"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDeclarativeWheelEvent[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
      10,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::Int, 0x00095401,
       2, QMetaType::Int, 0x00095401,
       3, QMetaType::Int, 0x00095401,
       4, QMetaType::Int, 0x00095401,
       5, QMetaType::Int, 0x00095401,
       6, QMetaType::Int, 0x00095401,
       7, QMetaType::Int, 0x00095401,
       8, 0x80000000 | 9, 0x00095409,
      10, 0x80000000 | 11, 0x00095409,
      12, 0x80000000 | 13, 0x00095409,

       0        // eod
};

void KDeclarativeWheelEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<KDeclarativeWheelEvent *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->screenX(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->screenY(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->deltaX(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->deltaY(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->deltaY(); break;
        case 7: *reinterpret_cast< Qt::MouseButtons*>(_v) = _t->buttons(); break;
        case 8: *reinterpret_cast< Qt::KeyboardModifiers*>(_v) = _t->modifiers(); break;
        case 9: *reinterpret_cast< Qt::Orientation*>(_v) = _t->orientation(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KDeclarativeWheelEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KDeclarativeWheelEvent.data,
    qt_meta_data_KDeclarativeWheelEvent,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KDeclarativeWheelEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDeclarativeWheelEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDeclarativeWheelEvent.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDeclarativeWheelEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
struct qt_meta_stringdata_MouseEventListener_t {
    QByteArrayData data[26];
    char stringdata0[372];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MouseEventListener_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MouseEventListener_t qt_meta_stringdata_MouseEventListener = {
    {
QT_MOC_LITERAL(0, 0, 18), // "MouseEventListener"
QT_MOC_LITERAL(1, 19, 7), // "pressed"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 23), // "KDeclarativeMouseEvent*"
QT_MOC_LITERAL(4, 52, 5), // "mouse"
QT_MOC_LITERAL(5, 58, 15), // "positionChanged"
QT_MOC_LITERAL(6, 74, 8), // "released"
QT_MOC_LITERAL(7, 83, 7), // "clicked"
QT_MOC_LITERAL(8, 91, 12), // "pressAndHold"
QT_MOC_LITERAL(9, 104, 10), // "wheelMoved"
QT_MOC_LITERAL(10, 115, 23), // "KDeclarativeWheelEvent*"
QT_MOC_LITERAL(11, 139, 5), // "wheel"
QT_MOC_LITERAL(12, 145, 20), // "containsMouseChanged"
QT_MOC_LITERAL(13, 166, 19), // "hoverEnabledChanged"
QT_MOC_LITERAL(14, 186, 12), // "hoverEnabled"
QT_MOC_LITERAL(15, 199, 22), // "acceptedButtonsChanged"
QT_MOC_LITERAL(16, 222, 18), // "cursorShapeChanged"
QT_MOC_LITERAL(17, 241, 14), // "pressedChanged"
QT_MOC_LITERAL(18, 256, 8), // "canceled"
QT_MOC_LITERAL(19, 265, 18), // "handlePressAndHold"
QT_MOC_LITERAL(20, 284, 12), // "handleUngrab"
QT_MOC_LITERAL(21, 297, 13), // "containsMouse"
QT_MOC_LITERAL(22, 311, 15), // "acceptedButtons"
QT_MOC_LITERAL(23, 327, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(24, 344, 11), // "cursorShape"
QT_MOC_LITERAL(25, 356, 15) // "Qt::CursorShape"

    },
    "MouseEventListener\0pressed\0\0"
    "KDeclarativeMouseEvent*\0mouse\0"
    "positionChanged\0released\0clicked\0"
    "pressAndHold\0wheelMoved\0KDeclarativeWheelEvent*\0"
    "wheel\0containsMouseChanged\0"
    "hoverEnabledChanged\0hoverEnabled\0"
    "acceptedButtonsChanged\0cursorShapeChanged\0"
    "pressedChanged\0canceled\0handlePressAndHold\0"
    "handleUngrab\0containsMouse\0acceptedButtons\0"
    "Qt::MouseButtons\0cursorShape\0"
    "Qt::CursorShape"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MouseEventListener[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       5,  114, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       5,    1,   87,    2, 0x06 /* Public */,
       6,    1,   90,    2, 0x06 /* Public */,
       7,    1,   93,    2, 0x06 /* Public */,
       8,    1,   96,    2, 0x06 /* Public */,
       9,    1,   99,    2, 0x06 /* Public */,
      12,    1,  102,    2, 0x06 /* Public */,
      13,    1,  105,    2, 0x06 /* Public */,
      15,    0,  108,    2, 0x06 /* Public */,
      16,    0,  109,    2, 0x06 /* Public */,
      17,    0,  110,    2, 0x06 /* Public */,
      18,    0,  111,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,  112,    2, 0x08 /* Private */,
      20,    0,  113,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      14, QMetaType::Bool, 0x00495103,
      21, QMetaType::Bool, 0x00495001,
      22, 0x80000000 | 23, 0x0049510b,
      24, 0x80000000 | 25, 0x0049510f,
       1, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       7,
       6,
       8,
       9,
      10,

       0        // eod
};

void MouseEventListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MouseEventListener *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->pressed((*reinterpret_cast< KDeclarativeMouseEvent*(*)>(_a[1]))); break;
        case 1: _t->positionChanged((*reinterpret_cast< KDeclarativeMouseEvent*(*)>(_a[1]))); break;
        case 2: _t->released((*reinterpret_cast< KDeclarativeMouseEvent*(*)>(_a[1]))); break;
        case 3: _t->clicked((*reinterpret_cast< KDeclarativeMouseEvent*(*)>(_a[1]))); break;
        case 4: _t->pressAndHold((*reinterpret_cast< KDeclarativeMouseEvent*(*)>(_a[1]))); break;
        case 5: _t->wheelMoved((*reinterpret_cast< KDeclarativeWheelEvent*(*)>(_a[1]))); break;
        case 6: _t->containsMouseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->hoverEnabledChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->acceptedButtonsChanged(); break;
        case 9: _t->cursorShapeChanged(); break;
        case 10: _t->pressedChanged(); break;
        case 11: _t->canceled(); break;
        case 12: _t->handlePressAndHold(); break;
        case 13: _t->handleUngrab(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDeclarativeMouseEvent* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDeclarativeWheelEvent* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MouseEventListener::*)(KDeclarativeMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::pressed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)(KDeclarativeMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::positionChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)(KDeclarativeMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::released)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)(KDeclarativeMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::clicked)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)(KDeclarativeMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::pressAndHold)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)(KDeclarativeWheelEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::wheelMoved)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::containsMouseChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::hoverEnabledChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::acceptedButtonsChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::cursorShapeChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::pressedChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (MouseEventListener::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseEventListener::canceled)) {
                *result = 11;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<MouseEventListener *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->hoverEnabled(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->containsMouse(); break;
        case 2: *reinterpret_cast< Qt::MouseButtons*>(_v) = _t->acceptedButtons(); break;
        case 3: *reinterpret_cast< Qt::CursorShape*>(_v) = _t->cursorShape(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isPressed(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<MouseEventListener *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHoverEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setAcceptedButtons(*reinterpret_cast< Qt::MouseButtons*>(_v)); break;
        case 3: _t->setCursorShape(*reinterpret_cast< Qt::CursorShape*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        MouseEventListener *_t = static_cast<MouseEventListener *>(_o);
        (void)_t;
        switch (_id) {
        case 3: _t->unsetCursor(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject MouseEventListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_MouseEventListener.data,
    qt_meta_data_MouseEventListener,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MouseEventListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MouseEventListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MouseEventListener.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int MouseEventListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void MouseEventListener::pressed(KDeclarativeMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MouseEventListener::positionChanged(KDeclarativeMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void MouseEventListener::released(KDeclarativeMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void MouseEventListener::clicked(KDeclarativeMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void MouseEventListener::pressAndHold(KDeclarativeMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void MouseEventListener::wheelMoved(KDeclarativeWheelEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void MouseEventListener::containsMouseChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void MouseEventListener::hoverEnabledChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void MouseEventListener::acceptedButtonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MouseEventListener::cursorShapeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MouseEventListener::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MouseEventListener::canceled()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
