/****************************************************************************
** Meta object code from reading C++ file 'fallbacktaphandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/fallbacktaphandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fallbacktaphandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_FallbackTapHandlerMouseEvent_t {
    QByteArrayData data[9];
    char stringdata0[113];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FallbackTapHandlerMouseEvent_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FallbackTapHandlerMouseEvent_t qt_meta_stringdata_FallbackTapHandlerMouseEvent = {
    {
QT_MOC_LITERAL(0, 0, 28), // "FallbackTapHandlerMouseEvent"
QT_MOC_LITERAL(1, 29, 6), // "button"
QT_MOC_LITERAL(2, 36, 15), // "Qt::MouseButton"
QT_MOC_LITERAL(3, 52, 7), // "buttons"
QT_MOC_LITERAL(4, 60, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(5, 77, 9), // "modifiers"
QT_MOC_LITERAL(6, 87, 21), // "Qt::KeyboardModifiers"
QT_MOC_LITERAL(7, 109, 1), // "x"
QT_MOC_LITERAL(8, 111, 1) // "y"

    },
    "FallbackTapHandlerMouseEvent\0button\0"
    "Qt::MouseButton\0buttons\0Qt::MouseButtons\0"
    "modifiers\0Qt::KeyboardModifiers\0x\0y"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FallbackTapHandlerMouseEvent[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       5,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, 0x80000000 | 2, 0x0009500b,
       3, 0x80000000 | 4, 0x0009500b,
       5, 0x80000000 | 6, 0x0009500b,
       7, QMetaType::QReal, 0x00095003,
       8, QMetaType::QReal, 0x00095003,

       0        // eod
};

void FallbackTapHandlerMouseEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<FallbackTapHandlerMouseEvent *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< Qt::MouseButton*>(_v) = _t->m_button; break;
        case 1: *reinterpret_cast< Qt::MouseButtons*>(_v) = _t->m_buttons; break;
        case 2: *reinterpret_cast< Qt::KeyboardModifiers*>(_v) = _t->m_modifiers; break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->m_x; break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->m_y; break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<FallbackTapHandlerMouseEvent *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (_t->m_button != *reinterpret_cast< Qt::MouseButton*>(_v)) {
                _t->m_button = *reinterpret_cast< Qt::MouseButton*>(_v);
            }
            break;
        case 1:
            if (_t->m_buttons != *reinterpret_cast< Qt::MouseButtons*>(_v)) {
                _t->m_buttons = *reinterpret_cast< Qt::MouseButtons*>(_v);
            }
            break;
        case 2:
            if (_t->m_modifiers != *reinterpret_cast< Qt::KeyboardModifiers*>(_v)) {
                _t->m_modifiers = *reinterpret_cast< Qt::KeyboardModifiers*>(_v);
            }
            break;
        case 3:
            if (_t->m_x != *reinterpret_cast< qreal*>(_v)) {
                _t->m_x = *reinterpret_cast< qreal*>(_v);
            }
            break;
        case 4:
            if (_t->m_y != *reinterpret_cast< qreal*>(_v)) {
                _t->m_y = *reinterpret_cast< qreal*>(_v);
            }
            break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject FallbackTapHandlerMouseEvent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_FallbackTapHandlerMouseEvent.data,
    qt_meta_data_FallbackTapHandlerMouseEvent,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FallbackTapHandlerMouseEvent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FallbackTapHandlerMouseEvent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FallbackTapHandlerMouseEvent.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FallbackTapHandlerMouseEvent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
struct qt_meta_stringdata_FallbackTapHandler_t {
    QByteArrayData data[10];
    char stringdata0[136];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FallbackTapHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FallbackTapHandler_t qt_meta_stringdata_FallbackTapHandler = {
    {
QT_MOC_LITERAL(0, 0, 18), // "FallbackTapHandler"
QT_MOC_LITERAL(1, 19, 7), // "pressed"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 29), // "FallbackTapHandlerMouseEvent*"
QT_MOC_LITERAL(4, 58, 5), // "event"
QT_MOC_LITERAL(5, 64, 6), // "tapped"
QT_MOC_LITERAL(6, 71, 8), // "released"
QT_MOC_LITERAL(7, 80, 22), // "acceptedButtonsChanged"
QT_MOC_LITERAL(8, 103, 15), // "acceptedButtons"
QT_MOC_LITERAL(9, 119, 16) // "Qt::MouseButtons"

    },
    "FallbackTapHandler\0pressed\0\0"
    "FallbackTapHandlerMouseEvent*\0event\0"
    "tapped\0released\0acceptedButtonsChanged\0"
    "acceptedButtons\0Qt::MouseButtons"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FallbackTapHandler[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       1,   44, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       5,    1,   37,    2, 0x06 /* Public */,
       6,    1,   40,    2, 0x06 /* Public */,
       7,    0,   43,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

 // properties: name, type, flags
       8, 0x80000000 | 9, 0x0049510b,

 // properties: notify_signal_id
       3,

       0        // eod
};

void FallbackTapHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FallbackTapHandler *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->pressed((*reinterpret_cast< FallbackTapHandlerMouseEvent*(*)>(_a[1]))); break;
        case 1: _t->tapped((*reinterpret_cast< FallbackTapHandlerMouseEvent*(*)>(_a[1]))); break;
        case 2: _t->released((*reinterpret_cast< FallbackTapHandlerMouseEvent*(*)>(_a[1]))); break;
        case 3: _t->acceptedButtonsChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FallbackTapHandlerMouseEvent* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FallbackTapHandlerMouseEvent* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FallbackTapHandlerMouseEvent* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FallbackTapHandler::*)(FallbackTapHandlerMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FallbackTapHandler::pressed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (FallbackTapHandler::*)(FallbackTapHandlerMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FallbackTapHandler::tapped)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (FallbackTapHandler::*)(FallbackTapHandlerMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FallbackTapHandler::released)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (FallbackTapHandler::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FallbackTapHandler::acceptedButtonsChanged)) {
                *result = 3;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<FallbackTapHandler *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< Qt::MouseButtons*>(_v) = _t->acceptedMouseButtons(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<FallbackTapHandler *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAcceptedButtons(*reinterpret_cast< Qt::MouseButtons*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject FallbackTapHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_FallbackTapHandler.data,
    qt_meta_data_FallbackTapHandler,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FallbackTapHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FallbackTapHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FallbackTapHandler.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int FallbackTapHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void FallbackTapHandler::pressed(FallbackTapHandlerMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void FallbackTapHandler::tapped(FallbackTapHandlerMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void FallbackTapHandler::released(FallbackTapHandlerMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void FallbackTapHandler::acceptedButtonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
