/****************************************************************************
** Meta object code from reading C++ file 'columnproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/columnproxymodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'columnproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ColumnProxyModel_t {
    QByteArrayData data[28];
    char stringdata0[355];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ColumnProxyModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ColumnProxyModel_t qt_meta_stringdata_ColumnProxyModel = {
    {
QT_MOC_LITERAL(0, 0, 16), // "ColumnProxyModel"
QT_MOC_LITERAL(1, 17, 16), // "rootIndexChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 29), // "considerRowsAboutToBeInserted"
QT_MOC_LITERAL(4, 65, 11), // "QModelIndex"
QT_MOC_LITERAL(5, 77, 26), // "considerRowsAboutToBeMoved"
QT_MOC_LITERAL(6, 104, 12), // "sourceParent"
QT_MOC_LITERAL(7, 117, 2), // "rA"
QT_MOC_LITERAL(8, 120, 2), // "rB"
QT_MOC_LITERAL(9, 123, 10), // "destParent"
QT_MOC_LITERAL(10, 134, 2), // "rD"
QT_MOC_LITERAL(11, 137, 28), // "considerRowsAboutToBeRemoved"
QT_MOC_LITERAL(12, 166, 19), // "considerRowsRemoved"
QT_MOC_LITERAL(13, 186, 17), // "considerRowsMoved"
QT_MOC_LITERAL(14, 204, 20), // "considerRowsInserted"
QT_MOC_LITERAL(15, 225, 19), // "considerDataChanged"
QT_MOC_LITERAL(16, 245, 4), // "idxA"
QT_MOC_LITERAL(17, 250, 4), // "idxB"
QT_MOC_LITERAL(18, 255, 15), // "sourceDestroyed"
QT_MOC_LITERAL(19, 271, 6), // "source"
QT_MOC_LITERAL(20, 278, 14), // "indexFromModel"
QT_MOC_LITERAL(21, 293, 19), // "QAbstractItemModel*"
QT_MOC_LITERAL(22, 313, 5), // "model"
QT_MOC_LITERAL(23, 319, 3), // "row"
QT_MOC_LITERAL(24, 323, 6), // "column"
QT_MOC_LITERAL(25, 330, 6), // "parent"
QT_MOC_LITERAL(26, 337, 7), // "indexAt"
QT_MOC_LITERAL(27, 345, 9) // "rootIndex"

    },
    "ColumnProxyModel\0rootIndexChanged\0\0"
    "considerRowsAboutToBeInserted\0QModelIndex\0"
    "considerRowsAboutToBeMoved\0sourceParent\0"
    "rA\0rB\0destParent\0rD\0considerRowsAboutToBeRemoved\0"
    "considerRowsRemoved\0considerRowsMoved\0"
    "considerRowsInserted\0considerDataChanged\0"
    "idxA\0idxB\0sourceDestroyed\0source\0"
    "indexFromModel\0QAbstractItemModel*\0"
    "model\0row\0column\0parent\0indexAt\0"
    "rootIndex"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ColumnProxyModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       2,  172, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    3,   85,    2, 0x08 /* Private */,
       5,    5,   92,    2, 0x08 /* Private */,
      11,    3,  103,    2, 0x08 /* Private */,
      12,    3,  110,    2, 0x08 /* Private */,
      13,    5,  117,    2, 0x08 /* Private */,
      14,    3,  128,    2, 0x08 /* Private */,
      15,    2,  135,    2, 0x08 /* Private */,
      18,    1,  140,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      20,    4,  143,    2, 0x42 /* Public | isScriptable */,
      20,    3,  152,    2, 0x62 /* Public | MethodCloned | isScriptable */,
      20,    2,  159,    2, 0x62 /* Public | MethodCloned | isScriptable */,
      26,    2,  164,    2, 0x42 /* Public | isScriptable */,
      26,    1,  169,    2, 0x62 /* Public | MethodCloned | isScriptable */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, 0x80000000 | 4, QMetaType::Int,    6,    7,    8,    9,   10,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, 0x80000000 | 4, QMetaType::Int,    2,    2,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,   16,   17,
    QMetaType::Void, QMetaType::QObjectStar,   19,

 // methods: parameters
    0x80000000 | 4, 0x80000000 | 21, QMetaType::Int, QMetaType::Int, 0x80000000 | 4,   22,   23,   24,   25,
    0x80000000 | 4, 0x80000000 | 21, QMetaType::Int, QMetaType::Int,   22,   23,   24,
    0x80000000 | 4, 0x80000000 | 21, QMetaType::Int,   22,   23,
    0x80000000 | 4, QMetaType::Int, 0x80000000 | 4,   23,   25,
    0x80000000 | 4, QMetaType::Int,   23,

 // properties: name, type, flags
      27, 0x80000000 | 4, 0x0049510b,
      24, QMetaType::Int, 0x00095103,

 // properties: notify_signal_id
       0,
       0,

       0        // eod
};

void ColumnProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ColumnProxyModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->rootIndexChanged(); break;
        case 1: _t->considerRowsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 2: _t->considerRowsAboutToBeMoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 3: _t->considerRowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->considerRowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 5: _t->considerRowsMoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 6: _t->considerRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 7: _t->considerDataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 8: _t->sourceDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 9: { QModelIndex _r = _t->indexFromModel((*reinterpret_cast< QAbstractItemModel*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 10: { QModelIndex _r = _t->indexFromModel((*reinterpret_cast< QAbstractItemModel*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 11: { QModelIndex _r = _t->indexFromModel((*reinterpret_cast< QAbstractItemModel*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 12: { QModelIndex _r = _t->indexAt((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 13: { QModelIndex _r = _t->indexAt((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QModelIndex*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ColumnProxyModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ColumnProxyModel::rootIndexChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ColumnProxyModel *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QModelIndex*>(_v) = _t->rootIndex(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->column(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ColumnProxyModel *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRootIndex(*reinterpret_cast< QModelIndex*>(_v)); break;
        case 1: _t->setColumn(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject ColumnProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_meta_stringdata_ColumnProxyModel.data,
    qt_meta_data_ColumnProxyModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ColumnProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColumnProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ColumnProxyModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int ColumnProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ColumnProxyModel::rootIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
