/****************************************************************************
** Meta object code from reading C++ file 'kwindowsystemproxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kwindowsystemplugin/kwindowsystemproxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwindowsystemproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KWindowSystemProxy_t {
    QByteArrayData data[29];
    char stringdata0[437];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KWindowSystemProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KWindowSystemProxy_t qt_meta_stringdata_KWindowSystemProxy = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KWindowSystemProxy"
QT_MOC_LITERAL(1, 19, 21), // "currentDesktopChanged"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 7), // "desktop"
QT_MOC_LITERAL(4, 50, 25), // "currentDesktopNameChanged"
QT_MOC_LITERAL(5, 76, 19), // "desktopNamesChanged"
QT_MOC_LITERAL(6, 96, 23), // "numberOfDesktopsChanged"
QT_MOC_LITERAL(7, 120, 16), // "numberOfDesktops"
QT_MOC_LITERAL(8, 137, 21), // "showingDesktopChanged"
QT_MOC_LITERAL(9, 159, 14), // "showingDesktop"
QT_MOC_LITERAL(10, 174, 24), // "compositingActiveChanged"
QT_MOC_LITERAL(11, 199, 17), // "compositingActive"
QT_MOC_LITERAL(12, 217, 9), // "hasWindow"
QT_MOC_LITERAL(13, 227, 8), // "QWindow*"
QT_MOC_LITERAL(14, 236, 6), // "window"
QT_MOC_LITERAL(15, 243, 19), // "forceActivateWindow"
QT_MOC_LITERAL(16, 263, 4), // "time"
QT_MOC_LITERAL(17, 268, 16), // "setOnAllDesktops"
QT_MOC_LITERAL(18, 285, 13), // "onAllDesktops"
QT_MOC_LITERAL(19, 299, 12), // "setOnDesktop"
QT_MOC_LITERAL(20, 312, 15), // "setOnActivities"
QT_MOC_LITERAL(21, 328, 10), // "activities"
QT_MOC_LITERAL(22, 339, 11), // "desktopName"
QT_MOC_LITERAL(23, 351, 14), // "setDesktopName"
QT_MOC_LITERAL(24, 366, 4), // "name"
QT_MOC_LITERAL(25, 371, 14), // "currentDesktop"
QT_MOC_LITERAL(26, 386, 18), // "currentDesktopName"
QT_MOC_LITERAL(27, 405, 13), // "isPlatformX11"
QT_MOC_LITERAL(28, 419, 17) // "isPlatformWayland"

    },
    "KWindowSystemProxy\0currentDesktopChanged\0"
    "\0desktop\0currentDesktopNameChanged\0"
    "desktopNamesChanged\0numberOfDesktopsChanged\0"
    "numberOfDesktops\0showingDesktopChanged\0"
    "showingDesktop\0compositingActiveChanged\0"
    "compositingActive\0hasWindow\0QWindow*\0"
    "window\0forceActivateWindow\0time\0"
    "setOnAllDesktops\0onAllDesktops\0"
    "setOnDesktop\0setOnActivities\0activities\0"
    "desktopName\0setDesktopName\0name\0"
    "currentDesktop\0currentDesktopName\0"
    "isPlatformX11\0isPlatformWayland"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KWindowSystemProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       7,  132, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       4,    0,   87,    2, 0x06 /* Public */,
       5,    0,   88,    2, 0x06 /* Public */,
       6,    1,   89,    2, 0x06 /* Public */,
       8,    1,   92,    2, 0x06 /* Public */,
      10,    1,   95,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      12,    1,   98,    2, 0x02 /* Public */,
      15,    2,  101,    2, 0x02 /* Public */,
      15,    1,  106,    2, 0x22 /* Public | MethodCloned */,
      17,    2,  109,    2, 0x02 /* Public */,
      19,    2,  114,    2, 0x02 /* Public */,
      20,    2,  119,    2, 0x02 /* Public */,
      22,    1,  124,    2, 0x02 /* Public */,
      23,    2,  127,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Bool,   11,

 // methods: parameters
    QMetaType::Bool, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Long,   14,   16,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Bool,   14,   18,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Int,   14,    3,
    QMetaType::Void, 0x80000000 | 13, QMetaType::QStringList,   14,   21,
    QMetaType::QString, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    3,   24,

 // properties: name, type, flags
      25, QMetaType::Int, 0x00495103,
      26, QMetaType::QString, 0x00495001,
       7, QMetaType::Int, 0x00495001,
       9, QMetaType::Bool, 0x00495103,
      11, QMetaType::Bool, 0x00495001,
      27, QMetaType::Bool, 0x00095401,
      28, QMetaType::Bool, 0x00095401,

 // properties: notify_signal_id
       0,
       1,
       3,
       4,
       5,
       0,
       0,

       0        // eod
};

void KWindowSystemProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KWindowSystemProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->currentDesktopChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->currentDesktopNameChanged(); break;
        case 2: _t->desktopNamesChanged(); break;
        case 3: _t->numberOfDesktopsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->showingDesktopChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->compositingActiveChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: { bool _r = _t->hasWindow((*reinterpret_cast< QWindow*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->forceActivateWindow((*reinterpret_cast< QWindow*(*)>(_a[1])),(*reinterpret_cast< long(*)>(_a[2]))); break;
        case 8: _t->forceActivateWindow((*reinterpret_cast< QWindow*(*)>(_a[1]))); break;
        case 9: _t->setOnAllDesktops((*reinterpret_cast< QWindow*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 10: _t->setOnDesktop((*reinterpret_cast< QWindow*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 11: _t->setOnActivities((*reinterpret_cast< QWindow*(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 12: { QString _r = _t->desktopName((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setDesktopName((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KWindowSystemProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWindowSystemProxy::currentDesktopChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (KWindowSystemProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWindowSystemProxy::currentDesktopNameChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (KWindowSystemProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWindowSystemProxy::desktopNamesChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (KWindowSystemProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWindowSystemProxy::numberOfDesktopsChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (KWindowSystemProxy::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWindowSystemProxy::showingDesktopChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (KWindowSystemProxy::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWindowSystemProxy::compositingActiveChanged)) {
                *result = 5;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<KWindowSystemProxy *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->currentDesktop(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->currentDesktopName(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->numberOfDesktops(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->showingDesktop(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->compositingActive(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isPlatformX11(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->isPlatformWayland(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<KWindowSystemProxy *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrentDesktop(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setShowingDesktop(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KWindowSystemProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KWindowSystemProxy.data,
    qt_meta_data_KWindowSystemProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KWindowSystemProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWindowSystemProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KWindowSystemProxy.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWindowSystemProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KWindowSystemProxy::currentDesktopChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KWindowSystemProxy::currentDesktopNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWindowSystemProxy::desktopNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KWindowSystemProxy::numberOfDesktopsChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KWindowSystemProxy::showingDesktopChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KWindowSystemProxy::compositingActiveChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
