/****************************************************************************
** Meta object code from reading C++ file 'qimageitem.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/qimageitem.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qimageitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QImageItem_t {
    QByteArrayData data[26];
    char stringdata0[325];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QImageItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QImageItem_t qt_meta_stringdata_QImageItem = {
    {
QT_MOC_LITERAL(0, 0, 10), // "QImageItem"
QT_MOC_LITERAL(1, 11, 18), // "nativeWidthChanged"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 19), // "nativeHeightChanged"
QT_MOC_LITERAL(4, 51, 15), // "fillModeChanged"
QT_MOC_LITERAL(5, 67, 12), // "imageChanged"
QT_MOC_LITERAL(6, 80, 11), // "nullChanged"
QT_MOC_LITERAL(7, 92, 19), // "paintedWidthChanged"
QT_MOC_LITERAL(8, 112, 20), // "paintedHeightChanged"
QT_MOC_LITERAL(9, 133, 17), // "updatePaintedRect"
QT_MOC_LITERAL(10, 151, 5), // "image"
QT_MOC_LITERAL(11, 157, 6), // "smooth"
QT_MOC_LITERAL(12, 164, 11), // "nativeWidth"
QT_MOC_LITERAL(13, 176, 12), // "nativeHeight"
QT_MOC_LITERAL(14, 189, 12), // "paintedWidth"
QT_MOC_LITERAL(15, 202, 13), // "paintedHeight"
QT_MOC_LITERAL(16, 216, 8), // "fillMode"
QT_MOC_LITERAL(17, 225, 8), // "FillMode"
QT_MOC_LITERAL(18, 234, 4), // "null"
QT_MOC_LITERAL(19, 239, 7), // "Stretch"
QT_MOC_LITERAL(20, 247, 17), // "PreserveAspectFit"
QT_MOC_LITERAL(21, 265, 18), // "PreserveAspectCrop"
QT_MOC_LITERAL(22, 284, 4), // "Tile"
QT_MOC_LITERAL(23, 289, 14), // "TileVertically"
QT_MOC_LITERAL(24, 304, 16), // "TileHorizontally"
QT_MOC_LITERAL(25, 321, 3) // "Pad"

    },
    "QImageItem\0nativeWidthChanged\0\0"
    "nativeHeightChanged\0fillModeChanged\0"
    "imageChanged\0nullChanged\0paintedWidthChanged\0"
    "paintedHeightChanged\0updatePaintedRect\0"
    "image\0smooth\0nativeWidth\0nativeHeight\0"
    "paintedWidth\0paintedHeight\0fillMode\0"
    "FillMode\0null\0Stretch\0PreserveAspectFit\0"
    "PreserveAspectCrop\0Tile\0TileVertically\0"
    "TileHorizontally\0Pad"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QImageItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       8,   62, // properties
       1,   94, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x06 /* Public */,
       3,    0,   55,    2, 0x06 /* Public */,
       4,    0,   56,    2, 0x06 /* Public */,
       5,    0,   57,    2, 0x06 /* Public */,
       6,    0,   58,    2, 0x06 /* Public */,
       7,    0,   59,    2, 0x06 /* Public */,
       8,    0,   60,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,   61,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

 // properties: name, type, flags
      10, QMetaType::QImage, 0x00495107,
      11, QMetaType::Bool, 0x00095103,
      12, QMetaType::Int, 0x00495001,
      13, QMetaType::Int, 0x00495001,
      14, QMetaType::Int, 0x00495001,
      15, QMetaType::Int, 0x00495001,
      16, 0x80000000 | 17, 0x0049510b,
      18, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       3,
       0,
       0,
       1,
       5,
       6,
       2,
       4,

 // enums: name, alias, flags, count, data
      17,   17, 0x0,    7,   99,

 // enum data: key, value
      19, uint(QImageItem::Stretch),
      20, uint(QImageItem::PreserveAspectFit),
      21, uint(QImageItem::PreserveAspectCrop),
      22, uint(QImageItem::Tile),
      23, uint(QImageItem::TileVertically),
      24, uint(QImageItem::TileHorizontally),
      25, uint(QImageItem::Pad),

       0        // eod
};

void QImageItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QImageItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->nativeWidthChanged(); break;
        case 1: _t->nativeHeightChanged(); break;
        case 2: _t->fillModeChanged(); break;
        case 3: _t->imageChanged(); break;
        case 4: _t->nullChanged(); break;
        case 5: _t->paintedWidthChanged(); break;
        case 6: _t->paintedHeightChanged(); break;
        case 7: _t->updatePaintedRect(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QImageItem::nativeWidthChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QImageItem::nativeHeightChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QImageItem::fillModeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QImageItem::imageChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QImageItem::nullChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QImageItem::paintedWidthChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QImageItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QImageItem::paintedHeightChanged)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QImageItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QImage*>(_v) = _t->image(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->smooth(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->nativeWidth(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->nativeHeight(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->paintedWidth(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->paintedHeight(); break;
        case 6: *reinterpret_cast< FillMode*>(_v) = _t->fillMode(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->isNull(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QImageItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setImage(*reinterpret_cast< QImage*>(_v)); break;
        case 1: _t->setSmooth(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setFillMode(*reinterpret_cast< FillMode*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        QImageItem *_t = static_cast<QImageItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->resetImage(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QImageItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_meta_stringdata_QImageItem.data,
    qt_meta_data_QImageItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QImageItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QImageItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QImageItem.stringdata0))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int QImageItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QImageItem::nativeWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QImageItem::nativeHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QImageItem::fillModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QImageItem::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QImageItem::nullChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QImageItem::paintedWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QImageItem::paintedHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
