// This file is generated by kconfig_compiler_kf5 from renderer.kcfg.
// All changes you do to this file will be lost.
#ifndef PLASMAQTQUICKSETTINGS_RENDERERSETTINGS_H
#define PLASMAQTQUICKSETTINGS_RENDERERSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace PlasmaQtQuickSettings {

class RendererSettings : public KConfigSkeleton
{
  public:

    RendererSettings( KSharedConfig::Ptr config = KSharedConfig::openConfig() );
    ~RendererSettings() override;

    /**
      Get RenderLoop
    */
    QString renderLoop() const
    {
      return mRenderLoop;
    }

    /**
      Is RenderLoop Immutable
    */
    bool isRenderLoopImmutable() const
    {
      return isImmutable( QStringLiteral( "RenderLoop" ) );
    }

    /**
      Get SceneGraphBackend
    */
    QString sceneGraphBackend() const
    {
      return mSceneGraphBackend;
    }

    /**
      Is SceneGraphBackend Immutable
    */
    bool isSceneGraphBackendImmutable() const
    {
      return isImmutable( QStringLiteral( "SceneGraphBackend" ) );
    }

    /**
      Get ForceGlCoreProfile
    */
    bool forceGlCoreProfile() const
    {
      return mForceGlCoreProfile;
    }

    /**
      Is ForceGlCoreProfile Immutable
    */
    bool isForceGlCoreProfileImmutable() const
    {
      return isImmutable( QStringLiteral( "ForceGlCoreProfile" ) );
    }

    /**
      Get GraphicsResetNotifications
    */
    bool graphicsResetNotifications() const
    {
      return mGraphicsResetNotifications;
    }

    /**
      Is GraphicsResetNotifications Immutable
    */
    bool isGraphicsResetNotificationsImmutable() const
    {
      return isImmutable( QStringLiteral( "GraphicsResetNotifications" ) );
    }

  protected:

    // QtQuickRendererSettings
    QString mRenderLoop;
    QString mSceneGraphBackend;
    bool mForceGlCoreProfile;
    bool mGraphicsResetNotifications;

  private:
};

}

#endif

