/****************************************************************************
** Meta object code from reading C++ file 'qiconitem.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../kdeclarative-5.116.0/src/qmlcontrols/kquickcontrolsaddons/qiconitem.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qiconitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QIconItem_t {
    QByteArrayData data[16];
    char stringdata0[164];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QIconItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QIconItem_t qt_meta_stringdata_QIconItem = {
    {
QT_MOC_LITERAL(0, 0, 9), // "QIconItem"
QT_MOC_LITERAL(1, 10, 11), // "iconChanged"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 13), // "smoothChanged"
QT_MOC_LITERAL(4, 37, 12), // "stateChanged"
QT_MOC_LITERAL(5, 50, 5), // "State"
QT_MOC_LITERAL(6, 56, 5), // "state"
QT_MOC_LITERAL(7, 62, 4), // "icon"
QT_MOC_LITERAL(8, 67, 6), // "smooth"
QT_MOC_LITERAL(9, 74, 13), // "implicitWidth"
QT_MOC_LITERAL(10, 88, 14), // "implicitHeight"
QT_MOC_LITERAL(11, 103, 7), // "enabled"
QT_MOC_LITERAL(12, 111, 12), // "DefaultState"
QT_MOC_LITERAL(13, 124, 11), // "ActiveState"
QT_MOC_LITERAL(14, 136, 13), // "DisabledState"
QT_MOC_LITERAL(15, 150, 13) // "SelectedState"

    },
    "QIconItem\0iconChanged\0\0smoothChanged\0"
    "stateChanged\0State\0state\0icon\0smooth\0"
    "implicitWidth\0implicitHeight\0enabled\0"
    "DefaultState\0ActiveState\0DisabledState\0"
    "SelectedState"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QIconItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       6,   34, // properties
       1,   58, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,
       3,    0,   30,    2, 0x06 /* Public */,
       4,    1,   31,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,

 // properties: name, type, flags
       7, QMetaType::QVariant, 0x00495103,
       8, QMetaType::Bool, 0x00495103,
       9, QMetaType::Int, 0x00095401,
      10, QMetaType::Int, 0x00095401,
       6, 0x80000000 | 5, 0x0049510b,
      11, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       0,
       0,
       2,
       2,

 // enums: name, alias, flags, count, data
       5,    5, 0x0,    4,   63,

 // enum data: key, value
      12, uint(QIconItem::DefaultState),
      13, uint(QIconItem::ActiveState),
      14, uint(QIconItem::DisabledState),
      15, uint(QIconItem::SelectedState),

       0        // eod
};

void QIconItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QIconItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->iconChanged(); break;
        case 1: _t->smoothChanged(); break;
        case 2: _t->stateChanged((*reinterpret_cast< State(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QIconItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QIconItem::iconChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QIconItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QIconItem::smoothChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QIconItem::*)(State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QIconItem::stateChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QIconItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QVariant*>(_v) = _t->icon(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->smooth(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->implicitWidth(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->implicitHeight(); break;
        case 4: *reinterpret_cast< State*>(_v) = _t->state(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->enabled(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QIconItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIcon(*reinterpret_cast< QVariant*>(_v)); break;
        case 1: _t->setSmooth(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setState(*reinterpret_cast< State*>(_v)); break;
        case 5: _t->setEnabled(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QIconItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_QIconItem.data,
    qt_meta_data_QIconItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QIconItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QIconItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QIconItem.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QIconItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QIconItem::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QIconItem::smoothChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QIconItem::stateChanged(State _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
