/****************************************************************************
** Meta object code from reading C++ file 'quickviewsharedengine.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kdeclarative-5.116.0/src/quickaddons/quickviewsharedengine.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quickviewsharedengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KQuickAddons__QuickViewSharedEngine_t {
    QByteArrayData data[18];
    char stringdata0[270];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KQuickAddons__QuickViewSharedEngine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KQuickAddons__QuickViewSharedEngine_t qt_meta_stringdata_KQuickAddons__QuickViewSharedEngine = {
    {
QT_MOC_LITERAL(0, 0, 35), // "KQuickAddons::QuickViewShared..."
QT_MOC_LITERAL(1, 36, 13), // "statusChanged"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 21), // "QQmlComponent::Status"
QT_MOC_LITERAL(4, 73, 6), // "status"
QT_MOC_LITERAL(5, 80, 17), // "resizeModeChanged"
QT_MOC_LITERAL(6, 98, 33), // "QuickViewSharedEngine::Resize..."
QT_MOC_LITERAL(7, 132, 10), // "resizeMode"
QT_MOC_LITERAL(8, 143, 13), // "sourceChanged"
QT_MOC_LITERAL(9, 157, 6), // "source"
QT_MOC_LITERAL(10, 164, 9), // "setSource"
QT_MOC_LITERAL(11, 174, 3), // "url"
QT_MOC_LITERAL(12, 178, 17), // "executionFinished"
QT_MOC_LITERAL(13, 196, 9), // "syncWidth"
QT_MOC_LITERAL(14, 206, 10), // "syncHeight"
QT_MOC_LITERAL(15, 217, 10), // "ResizeMode"
QT_MOC_LITERAL(16, 228, 20), // "SizeViewToRootObject"
QT_MOC_LITERAL(17, 249, 20) // "SizeRootObjectToView"

    },
    "KQuickAddons::QuickViewSharedEngine\0"
    "statusChanged\0\0QQmlComponent::Status\0"
    "status\0resizeModeChanged\0"
    "QuickViewSharedEngine::ResizeMode\0"
    "resizeMode\0sourceChanged\0source\0"
    "setSource\0url\0executionFinished\0"
    "syncWidth\0syncHeight\0ResizeMode\0"
    "SizeViewToRootObject\0SizeRootObjectToView"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KQuickAddons__QuickViewSharedEngine[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       3,   64, // properties
       1,   76, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       5,    1,   52,    2, 0x06 /* Public */,
       8,    1,   55,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,   58,    2, 0x0a /* Public */,
      12,    0,   61,    2, 0x08 /* Private */,
      13,    0,   62,    2, 0x08 /* Private */,
      14,    0,   63,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::QUrl,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       7, 0x80000000 | 15, 0x0049510b,
       4, 0x80000000 | 3, 0x00495009,
       9, QMetaType::QUrl, 0x00495103,

 // properties: notify_signal_id
       1,
       0,
       2,

 // enums: name, alias, flags, count, data
      15,   15, 0x0,    2,   81,

 // enum data: key, value
      16, uint(KQuickAddons::QuickViewSharedEngine::SizeViewToRootObject),
      17, uint(KQuickAddons::QuickViewSharedEngine::SizeRootObjectToView),

       0        // eod
};

void KQuickAddons::QuickViewSharedEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QuickViewSharedEngine *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast< QQmlComponent::Status(*)>(_a[1]))); break;
        case 1: _t->resizeModeChanged((*reinterpret_cast< QuickViewSharedEngine::ResizeMode(*)>(_a[1]))); break;
        case 2: _t->sourceChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 3: _t->setSource((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 4: _t->d->executionFinished(); break;
        case 5: _t->d->syncWidth(); break;
        case 6: _t->d->syncHeight(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QuickViewSharedEngine::*)(QQmlComponent::Status );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QuickViewSharedEngine::statusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QuickViewSharedEngine::*)(QuickViewSharedEngine::ResizeMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QuickViewSharedEngine::resizeModeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QuickViewSharedEngine::*)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QuickViewSharedEngine::sourceChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QuickViewSharedEngine *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< ResizeMode*>(_v) = _t->resizeMode(); break;
        case 1: *reinterpret_cast< QQmlComponent::Status*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast< QUrl*>(_v) = _t->source(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QuickViewSharedEngine *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setResizeMode(*reinterpret_cast< ResizeMode*>(_v)); break;
        case 2: _t->setSource(*reinterpret_cast< QUrl*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_KQuickAddons__QuickViewSharedEngine[] = {
    QMetaObject::SuperData::link<QQmlComponent::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject KQuickAddons::QuickViewSharedEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWindow::staticMetaObject>(),
    qt_meta_stringdata_KQuickAddons__QuickViewSharedEngine.data,
    qt_meta_data_KQuickAddons__QuickViewSharedEngine,
    qt_static_metacall,
    qt_meta_extradata_KQuickAddons__QuickViewSharedEngine,
    nullptr
} };


const QMetaObject *KQuickAddons::QuickViewSharedEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KQuickAddons::QuickViewSharedEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KQuickAddons__QuickViewSharedEngine.stringdata0))
        return static_cast<void*>(this);
    return QQuickWindow::qt_metacast(_clname);
}

int KQuickAddons::QuickViewSharedEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KQuickAddons::QuickViewSharedEngine::statusChanged(QQmlComponent::Status _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KQuickAddons::QuickViewSharedEngine::resizeModeChanged(QuickViewSharedEngine::ResizeMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KQuickAddons::QuickViewSharedEngine::sourceChanged(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
